package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$!`0````````````(`*``!````N1H!`#0```!XLP```@0`!30`(``)
M`"@`'``;``$``'"DIP``I*<!`*2G`0`(````"`````0````$````!@```#0`
M```T``$`-``!`"`!```@`0``!0````0````#````5`$``%0!`0!4`0$`&0``
M`!D````$`````0````$````````````!`````0"PIP``L*<```4```````$`
M`0```/2N``#TK@(`]*X"`$`"``"($@``!@```````0`"`````*\```"O`@``
MKP(```$````!```&````!`````0```!P`0``<`$!`'`!`0!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71D]*X`
M`/2N`@#TK@(`#`$```P!```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````$`````$```!'3E4```````(````&````(`````0````4
M`````P```$=.50!E*NH=N^/?TVN).@&([4%G>82<=&$````%````(`````H`
M``"@$@`(`D01(``"0`!6`'`8P@@`,`@`%1$``!`"`"@`````````2`(@"@`*
M``2$`ZA`"$5@:0"$"3Y"/)<``0`()%B`!`E@#)-X"4):`$``0``!`$()`$"`
MC,"$```0D!"#"0`(`1"`@4!`P@F`+$"8`D$`(``@!`F`E`&D#I=V0`4`````
M````!@````<````)``````````````````````````H````,````#@```!``
M```1````$@```!0````7`````````!D``````````````!H````=````'@``
M```````B````(P```"0`````````)0```"8````J`````````"P`````````
M`````"T````N````+P```#``````````-````#4`````````.0``````````
M````.@```#T````^`````````#\```!`````0@```$0```!'`````````$H`
M``!+````3````$T`````````3@``````````````````````````````````
M`$\```!0`````````%(`````````5````%8```!8````````````````````
M`````%D```!=`````````%\`````````80````````!C````9```````````
M````9@```&<```!I````:@```&T```!?EI,<HUKOD%;;DQS#CH?_#3J7"])1
M!(2!=((->O!*:WU!CL5V5#R4S3\,K_<CSB")!W#3('2P`M5DU'QFK\QF+DX]
M]MOW`%X&I(?_`:\TZ+%(G>?.2J[_SMY'+>&G`@KC1\8!Q@[@/3Y^EGSL/Y`"
M;7.%Q<6)!9!AF.\2`2/YI)V[DQQ"1=7L4.X1XX;YG(%][1$/NI63'%N:.P]!
M39U\I]VC:UGOEWDY\HL<#!3BG@0RI86B`O89V\WCGONA;&#JT^\.R#E`'S)B
MV^VYC?$.Z?O#PDHB??\*BA!7[=Z3'*U+X\#9<5@<*]#A(AJ?UKTM#K%S6#M`
M'\/E/RR8(M1HNN.2?"'_Y`Z*F-W";GII^HO9-5>3K01B-^/PP4/R[\C?A2!/
M5Z2;EL6YG$!0&WU?,;B"#;[:5QNS`8MOO-!+?7=OXW!J"4/6GR+'J"%B9`=^
MJ9R;8M#Z@NPL]HMK?YI\AO"6?-&?+/SN"U'Y\]O3'9!U@@U#9DL0!6RRS3RM
M.0T7ZEKQH^#[2>)7Q!A7DEI2_=+O#V[%WQ]\D!#I+=_^2"[%F[;>J\J?R=6R
M<0`````````````````````1```````````````@````+0``````````````
M(````#P``````````````"````!0```````````````@````A`,`````````
M````$@```$<"`````````````!(```#>`@`````````````2````P@(`````
M````````$@```'<$```DL0(``````"``%P#-`0`````````````2````NP(`
M````````````$@```+T!``#L%0$``````!(````#!0``"6<!`#`````2``T`
MX`,``#2Q`@``````$``8`'4"`````````````!(```"@`@`````````````2
M````MP0``#"Q`@`$````$0`7`"$#`````````````!(````?!0``Z6,!`-0"
M```2``T`7`0``"59`0"H````$@`-`(L#`````````````!(```"&`@``````
M```````2````,@,`````````````$@```.\#``!\P0(``````!``&``/`0``
M```````````2````.@0`````````````$@```&@$``!Q7`$`>`<``!(`#0"1
M!```]58!`)(````2``T`3P0```U9`0`6````$@`-`*T"`````````````!(`
M``!P`@`````````````2````E@$`````````````$@````X#````````````
M`!(```">`P``.+$"``0````A`!@`+P(`````````````$@```#8"````````
M`````!(```#0`@`````````````2````S0,``#2Q`@``````$``7`.L"````
M`````````!(```">````+!@!```````2````M0(`````````````$@```%8#
M`````````````!(````I`@`````````````2````3P(`````````````$@``
M`)\#```XL0(`!````"$`&`#Z`P``?,$"```````0`!@`*P,``%"Q`@`$````
M$0`8``<$``")9P$``@```!(`#0"A`0`````````````2````;P$`````````
M````$@```*<$``!)9P$`0````!(`#0#C!```M5L!`+P````2``T`$00``(QG
M`0``````$@`.`(\"`````````````!(```![!```N1H!```````2``T`T`0`
M`%05`0``````$@`+`+X``````````````!(``````P`````````````2````
M`@$``$RQ`@`!````$0`8`,D"`````````````!(```""!```E&<!``0````1
M``\`U`,``#2Q`@``````$``8`%T#`````````````!(```!U`P``````````
M```2````:@``````````````$@```!P!`````````````!(```#.!```@58!
M`#`````2``T`.`$`````````````$@````($``!\P0(``````!``&`#6!```
MC5<!`'X!```2``T`TP``````````````$@```%X"`````````````!(```"'
M```````````````2````%0(`````````````$@```*\!`````````````!(`
M``#A```````````````2````\P``````````````$@```"T!``!(L0(`!```
M`!$`&`"=`P``.+$"``0````1`!@`80$`````````````$@```-<"````````
M`````!(```#N`P``?,$"```````0`!@`]00``%5;`0!0````$@`-`*\`````
M`````````!(````9`P`````````````2````=00``"2Q`@``````$``7`&<#
M`````````````!(```"[`P``0+$"``0````1`!@`*`0``*5;`0`0````$@`-
M`.L!`````````````!(```#8`0`````````````2````F`,``,$8`0#X`0``
M$@`-`#T!`````````````!(```!"`P`````````````2````.0,`````````
M````$@```/8!``!4L0(`$P```!$`&`#Y`@`````````````2````Y0(`````
M````````$@```'T"`````````````!(```#D`0`````````````2````?0,`
M````````````$@```,$$``#-60$`B`$``!(`#0!)`P`````````````2````
M0@$`````````````$@```*<"`````````````!(```!#!```O68!`$P````2
M``T`>```````````````$@```'\!`````````````!(````7!```B5<!``0`
M```2``T`B`$`````````````$@```$X!``"T%P$``````!(`````;&EB<&5R
M;"YS;RXU+C(P`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?7V=M;VY?
M<W1A<G1?7P!?2G9?4F5G:7-T97)#;&%S<V5S`%])5$U?<F5G:7-T97)434-L
M;VYE5&%B;&4`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!097)L7W-A
M=F5?9&5S=')U8W1O<E]X`%!E<FQ?871F;W)K7VQO8VL`<&5R;%]C;VYS=')U
M8W0`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]A=E]S:&EF=`!097)L7W-V
M7S)P=E]F;&%G<P!097)L7W-V7W-E='!V;@!03%]D;U]U;F1U;7``4&5R;%]N
M97=35G!V`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R964`
M4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`
M4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?9&]U;G=I;F0`4&5R;%]N
M97=84P!P97)L7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A
M9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`
M4$Q?;65M;W)Y7W=R87``;&EB<'1H<F5A9"YS;RXP`'!T:')E861?9V5T<W!E
M8VEF:6,`8VQO<V4`;W!E;C8T`%]?97)R;F]?;&]C871I;VX`;'-E96LV-`!R
M96%D`&QI8F,N<V\N-@!?7W)E9VES=&5R7V%T9F]R:P!E>&ET`'-T<FYC;7``
M7U]S=')D=7``8VQO<V5D:7(`7U]S=&%C:U]C:&M?9F%I;`!U;FQI;FL`;6MD
M:7(`<F5A;&QO8P!A8F]R=`!M96UC:'(`9V5T<&ED`'-T<G1O:P!S=')L96X`
M;65M<V5T`'-T<G-T<@!R;61I<@!?7V9P<FEN=&9?8VAK`&UE;6-P>0!?7W-T
M<FYC<'E?8VAK`%]?;'AS=&%T-C0`;W!E;F1I<@!?7WAS=&%T-C0`<W1D97)R
M`&=E='5I9`!R96%D;&EN:P!E>&5C=G``7U]M96UC<'E?8VAK`'-T<F-H<@!R
M96%D9&ER-C0`7U]S<')I;G1F7V-H:P!M96UM;W9E`&%C8V5S<P!S=')C;7``
M7U]L:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N`&QD+6QI;G5X+6%R;6AF+G-O
M+C,`7U]S=&%C:U]C:&M?9W5A<F0`7V5D871A`%]?8G-S7W-T87)T`%]?8G-S
M7W-T87)T7U\`7U]B<W-?96YD7U\`7U]E;F1?7P!?96YD`%]?;&EB8U]C<W5?
M9FEN:0!P87)?8W5R<F5N=%]E>&5C`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W
M=6ED`'!A<E]C;&5A;G5P`'!A<E]B87-E;F%M90!P87)?9&ER;F%M90!P87)?
M;6MT;7!D:7(`7U]D871A7W-T87)T`%])3U]S=&1I;E]U<V5D`'!A<E]C=7)R
M96YT7V5X96-?<')O8P!?7VQI8F-?8W-U7VEN:70`;7E?<&%R7W!L`'!A<E]I
M;FET7V5N=@!X<U]I;FET`'!A<E]F:6YD<')O9P!P87)?<V5T=7!?;&EB<&%T
M:`!P87)?96YV7V-L96%N`%A37TEN=&5R;F%L<U]005)?0TQ%05)35$%#2P!8
M4U]);G1E<FYA;'-?4$%27T)/3U0`1TQ)0D-?,BXT`````````````````@`#
M``(``@`!`````@````$``0`"``(``0`"``$``0`"``(``@`!`````@`!``$`
M`0`"``(````"``(``P`#``(``0`"`````@`"``,``P`"``$``@`!```````!
M``$``0`"``$``0````(````"``$``0`"``(```````$````!``$````"````
M`P````````````(````"``$``0````(``0`"``0``0```````0`"``(``@``
M``(``@`"``(``@`!``(````"``$```````$```````$``0"G`P``$````"``
M```4:6D-```$`#4%`````````0`!``4"```0````(````!1I:0T```,`-04`
M```````!``$`5`(``!``````````%&EI#0```@`U!0```````""Q`@`5`@``
M.+$"`!1/``!`L0(`%%@``$BQ`@`43@``3+$"`!0[``!0L0(`%"\``%2Q`@`4
M8```#+`"`!8'```0L`(`%@4``!2P`@`6&@``&+`"`!8L```<L`(`%A<``""P
M`@`60```)+`"`!9=```HL`(`%D<``"RP`@`680``,+`"`!9>```TL`(`%@P`
M`#BP`@`68@``/+`"`!94``!`L`(`%D0``$2P`@`6.@``2+`"`!8V``!,L`(`
M%D@``%"P`@`6$```5+`"`!8>``!8L`(`%C$``%RP`@`64```8+`"`!9?``!D
ML`(`%F<``&BP`@`63```;+`"`!9:``!PL`(`%@8``'2P`@`6;@``>+`"`!9;
M``!\L`(`%E4``("P`@`6(P``A+`"`!9D``"(L`(`%A4``(RP`@`6,@``D+`"
M`!8"``"4L`(`%@@``)BP`@`6'P``G+`"`!8E``"@L`(`%FL``*2P`@`6*@``
MJ+`"`!89``"LL`(`%B0``+"P`@`65P``M+`"`!8Y``"XL`(`%F,``+RP`@`6
M(```P+`"`!9I``#$L`(`%E$``,BP`@`6;P``S+`"`!9!``#0L`(`%F@``-2P
M`@`6"@``V+`"`!8G``#<L`(`%D(``."P`@`6"P``Y+`"`!9E``#HL`(`%CP`
M`.RP`@`62P``\+`"`!8H``#TL`(`%C\``/BP`@`630``_+`"`!9L````L0(`
M%DD```2Q`@`6$@``"+$"`!8/```,L0(`%BD``!"Q`@`6*P``%+$"`!8A```8
ML0(`%A8``!RQ`@`62@``"$`MZ6(!`.L(@+WH!.`MY03@G^4.X(_@"/"^Y9":
M`0``QH_B&<J,XI#ZO.4`QH_B&<J,XHCZO.4`QH_B&<J,XH#ZO.4`QH_B&<J,
MXGCZO.4`QH_B&<J,XG#ZO.4`QH_B&<J,XFCZO.4`QH_B&<J,XF#ZO.4`QH_B
M&<J,XECZO.4`QH_B&<J,XE#ZO.4`QH_B&<J,XDCZO.4`QH_B&<J,XD#ZO.4`
MQH_B&<J,XCCZO.4`QH_B&<J,XC#ZO.4`QH_B&<J,XBCZO.4`QH_B&<J,XB#Z
MO.4`QH_B&<J,XACZO.5X1\!&`,:/XAG*C.(,^KSE`,:/XAG*C.($^KSE`,:/
MXAG*C.+\^;SE`,:/XAG*C.+T^;SE`,:/XAG*C.+L^;SE`,:/XAG*C.+D^;SE
M`,:/XAG*C.+<^;SE`,:/XAG*C.+4^;SE`,:/XAG*C.+,^;SE`,:/XAG*C.+$
M^;SE`,:/XAG*C.*\^;SE`,:/XAG*C.*T^;SE`,:/XAG*C.*L^;SE`,:/XAG*
MC.*D^;SE`,:/XAG*C.*<^;SE`,:/XAG*C.*4^;SE`,:/XAG*C.*,^;SE`,:/
MXAG*C.*$^;SE`,:/XAG*C.)\^;SE`,:/XAG*C.)T^;SE`,:/XAG*C.)L^;SE
M`,:/XAG*C.)D^;SE`,:/XAG*C.)<^;SE`,:/XAG*C.)4^;SE`,:/XAG*C.),
M^;SE`,:/XAG*C.)$^;SE`,:/XAG*C.(\^;SE>$?`1@#&C^(9RHSB,/F\Y7A'
MP$8`QH_B&<J,XB3YO.4`QH_B&<J,XASYO.4`QH_B&<J,XA3YO.4`QH_B&<J,
MX@SYO.4`QH_B&<J,X@3YO.4`QH_B&<J,XOSXO.4`QH_B&<J,XO3XO.4`QH_B
M&<J,XNSXO.4`QH_B&<J,XN3XO.4`QH_B&<J,XMSXO.4`QH_B&<J,XM3XO.4`
MQH_B&<J,XLSXO.4`QH_B&<J,XL3XO.4`QH_B&<J,XKSXO.4`QH_B&<J,XK3X
MO.4`QH_B&<J,XJSXO.4`QH_B&<J,XJ3XO.5X1\!&`,:/XAG*C.*8^+SE`,:/
MXAG*C.*0^+SE`,:/XAG*C.*(^+SE`,:/XAG*C.*`^+SE`,:/XAG*C.)X^+SE
M`,:/XAG*C.)P^+SE`,:/XAG*C.)H^+SE`,:/XAG*C.)@^+SE+>GP0TOR0!G`
M\@()B;#9^``P!9`%J`21!*D#D@.J!Y/_]RCO0?*T<D'V+`#`\@$"P/(!`!%&
M!/`?_TOR3!/`\@(#'7@`+0#PD8!+\D@4P/("!"!H__?.[Y#XWC,"1B!H0_`"
M`X+XWC/_]\3O!9N?[5Y;!3,'[I`ZG^U=:[CN9WLW[@5[M.[&>_'N$/J0^-XC
M0O`!`H#XWB,`\XF`F`!,\F`H__>L[@2>2_(L$P6:P/("`\#R`@A<:`$J1O8H
M,4;V+#/`\@$!P/(!`P=&,&A(^/!\O&#(OP?Q#`0X8$_P!`!Y8,B_,1W[8,B_
M!NN"!DCX]`P%W5'X!%NQ0D3X!%_YT0+Q@$1%\K%A`S0`)3M&`)58^.@,`S)'
M^"10P/(!`?_W_.Y,\F`CP/("`P1&F+-8^.@,3/)@)?_W,NY&]M@`!JG`\@$`
MP/("!0/PROM(LUCXZ`S_]_[M__?4[@>:V?@`,"!&FD(YT0FPO>CP@__W-.Y,
M\F`CP/("`T/XZ`QXLTOR2!3_]^#MP/("!"!H__<R[X#X+59=YU/XZ`S_]_KN
M!$;%YU7X[`Q@L03P*/[/YTOR5!%&]@0@P/("`<#R`0#_]WCN1O9T``:IP/(!
M``/PB/M%^.P,`"BZT.;G__?&[0$@__<\[J_S`(``````````````@/___\]!
M3_``"T_P``X"O&I&!+0!M-_X$,!-^`3-`T@$2__W"N[_]]3NB6<!`,$8`0!)
M9P$`%#"?Y10@G^4#,(_@`B"3YP``4N,>_R\!__[_Z@B5`0`@`0``!TM+\C00
MP/("`!L:!BL%V4#R``/`\@`#`[$81W!'`+\WL0(`2_(T$TOR-!#`\@(#P/("
M`!D:B1`!Z]%Q21`%T$#R``/`\@`#`[$81W!'`+\0M4OR9Q3`\@($(W@;N?_W
MS_\!(R-P$+U*]OQ@"+7`\@(``V@3N;WH"$#3YT#R``/`\@`#`"OVT)A'].<M
MZ?!/2_)`$ZWU/WW`\@(#`D8X,@WQ>`D;DQMH`48:D`'Q>`P01DY&!T:]D\WX
M*)#-Z0RKE^@*``@W9T5/ZA-K3^H3)4_J$6I/Z@$B2NH#*D_J$20`DD3J`V3-
M^`2@3^H#(D_J`VX"DMWI`"-/\``#F49/Z@%A!/1_0`+T?P)/\``#S?@,L`63
M2T9"Z@$"3_```8!&B4;=Z0(!3_```025`/1_`,WX&+!`Z@X`S>D(`4!&0.H"
M`$_P``$'D4E&0>H#`0)&"O#_``M&0NH`"$_P``%#Z@$)W>D$$D_P``)&Z0*)
M`?1_00A&$4;=Z0@C0NH``D/J`0,01AE&W>D&(T_P``-#Z@$#`O#_`D+J``(9
M1A!&YN@$`8W1W?@HD#2H*JD-\6@.#?'H#$_P0`CYZ0)G\>D"(_#I`D7-Z0!G
M@NH$!H/J!0?^Z0)%,D8[1MWI`&=60%]`9D!O0+09N/$!"$_JUGI/\``#2NI'
M"DKJ!`8R1NSI`B/:T1J<#?4^?G[IH@'4Z0`C)4;-Z00!%T:81@`B`"/Y#LWI
M`B,"D9)&U.D(`2Q&U>D"5IM&S>D`>'H!S>D4`0*9S>D,5D5&0>I($0*1Z0X#
MD=3I!@$E1MWI%(G5Z01GS>D.`=WI!`$/]NQ4U.D`-!#K"`#-Z0IG0>L)`=WI
M`HD;&-WI#E9,04CJ`@C=Z0P2S>D$-"7J`0,FZ@($#D8E1AQ&$T8*1MWI"@$?
M1@9`#T!01EE&S>D"`3U#W>D$`1]&3^J2"C1#2NJ'>A#K"`!/ZH=S3_``!@.3
M3_``!\WX#*!/ZH)S`I-!\0`!,T80ZP0(/$;-Z00TW>D"(T'K!0G-Z0B)3_``
M"T+J"@+>Z0)%3_``"4_JV&801MWI`"-/ZDD1!9$"Z@`*648#Z@$+S>D"J]WI
M#KQ&ZDD6S>D&`1OK!`O=Z0H!3.L%#`667$;=Z0*K(.H"`B'J`P-*Z@(*3^I(
M$0212^H#"P_V[$+2Z0`2`"`)&4+K#`(31@I&`"'-Z0(!W>D$`3!#$NL*!D/K
M"P?=Z0"K,AA31A9&3^J3`P*3`II'\0`#44:R1A]&0NJ+<UI&`I.3"`.3`"(`
M(\WI!".,!]WI`B-/\``+S>D09_8.!)8B0P2;`"<61M[I!$5#ZDL3!)/=Z0@C
M3^I*$,WI"&<R0#M`%D8?1MWI"B,2&4_JVV1K0064#_901=7I`$6D&#)&74'-
MZ1)%W>D&-"/J"`,DZ@D$)48<1CM&(D,K0]WI!&<41@`B'48`(\WI`B,&0]WI
M$A)/ZI@#`I-/ZHAP"1EJ015&BAE%\0`#`"$<1A-&`IJ81LWI$C1/ZMAF0NJ)
M<@*23^J9`@.2W>D"(P`CWND&14_P``D"0T;J21801@`BS>D"(P_VP#/3Z0`C
M$AE/ZDD4:T$#E-WI$$7-Z1`!!$`-0-WI!@$#EH`864'-Z00!W>D(`2'J"P$@
MZ@H`"T8I1AE#`D8@1MWI!$400PM&3^I($0*1)!C=Z0(!74$`(C!#`"/-Z00C
M(AA/ZIH#!)-%\0`#3^J*=@`A'$831@2:FD;-Z18T`"1"ZHMR!))/ZIL"!9+=
MZ00CHT8`(][I"$4R0T_JVF9&ZDL6$$8`(LWI`B,/]A0ST^D`(\WI!@$2&4_J
M2Q1K00.4W>D210.6!$`-0-WI"`&`&%E!W>D0(\WI!`$I1B/J"0,BZ@@"&4,@
M1A!#`"(+1D_J2A$"D=WI!$4D&-WI`@%=00`C,$/-Z00C(AA/ZI@#!)-%\0`#
M$49/ZHAV&D8$F\WI$A*(1D/JB7,$DT_JF0,%D]WI!",`(][I"D5/\``),D,`
M(4_JV&801@`BS>D"(T;J218/]FPCT^D`(\WI"`$2&4_J211K00.4W>D610.6
M!$`-0-WI$`&`&%E!W>D&(\WI!`$I1B/J"P,BZ@H"&4,@1MWI!$400PM&3^I(
M$0*1)!C=Z0(!74$`(@`C,$/-Z00C(AA/ZIH#!)-%\0`#3^J*=@`A'$831@2:
MFD;-Z18T`"1"ZHMR!))/ZIL"!9+=Z00CHT8`(][I#$4R0T_JVF9&ZDL6$$8`
M(LWI`B,/]L03T^D`(\WI$`$2&4_J2Q1K00.4W>D210.6!$`-0-WI!@&`&%E!
MW>D((\WI!`$I1B/J"0,BZ@@"&4,@1MWI!$400PM&3^I*$0*1)!C=Z0(!74$`
M(@`C,$/-Z00C(AA/ZI@#!)-%\0`#$49/ZHAV&D8$F\WI$A*(1D/JB7,$DT_J
MF0,%D]WI!",`(][I#D5/\``),D,`(4_JV&801@`BS>D"(T;J218/]AP3T^D`
M(\WI!@$2&4_J211K00.4W>D610.6!$`-0-WI"`&`&%E!W>D0(\WI!`$I1B/J
M"P,BZ@H"&4,@1MWI!$400PM&3^I($0*1)!C=Z0(!74$`(@`C,$/-Z00C(AA/
MZIH#!)-%\0`#3^J*=@`A'$831@2:FD;-Z18T`"1"ZHMR!))/ZIL"!9+=Z00C
MHT8`(][I$$4R0T_JVF9&ZDL6$$8`(LWI`B,/]G0#T^D`(\WI"`$2&4_J2Q1K
M00.4W>D210.6!$`-0-WI$`&`&%E!W>D&(\WI!`$I1B/J"0,BZ@@"&4,@1MWI
M!$400PM&3^I*$0*1)!C=Z0(!74$`(@`C,$/-Z00C(AA/ZI@#!)-%\0`#$49/
MZHAV&D8$F\WI$A*(1D/JB7,$DT_JF0,%D]WI!",`(][I$D5/\``),D,`(4_J
MV&801@`BS>D"(T;J218/\LQST^D`(\WI$`$2&4_J211K00.4W>D610.6!$`-
M0-WI!@&`&%E!W>D((\WI!`$I1B/J"P,BZ@H"&4,@1MWI!$400PM&3^I($0*1
M)!C=Z0(!74$`(@`C,$/-Z00C(AA/ZIH#!)-%\0`#3^J*=@`A'$831@2:FD9"
MZHMR!))/ZIL"!9+-Z18T`"3=Z00CHT8`(][I%$4R0T_JVF9&ZDL6$$8`(LWI
M`B,/\B1ST^D`(\WI!@$2&4_J2Q1K00.4W>D210.6!$`-0-WI"`&`&%E!W>D0
M(\WI!`$I1B/J"0,BZ@@"&4,@1MWI!$400PM&3^I*$0*1)!C=Z0(!74$`(@`C
M,$/-Z00C(AA/ZI@#!)-%\0`#$49/ZHAV&D8$F\WI$A*(1D/JB7,$DT_JF0,%
MD]WI!",`(][I%D5/\``),D,`(4_JV&801@`BS>D"(T;J218/\GQCT^D`(\WI
M"`$2&4_J211K00.4W>D610.6!$`-0-WI$`&`&%E!W>D&(\WI!`$@1B/J"P,B
MZ@H"*4;=Z01%&4,00R083_```@M&3^I($0*174$`(\WI!"/=Z0(!3^J:`P23
M`"$P0T_JBG8B&$7Q``,<1A-&!)J:1LWI%C0`)$+JBW($DD_JFP(%DMWI!".C
M1@`CWND813)#3^K:9D;J2Q801@`BS>D"(P_RU%/3Z0`CS>D0`1(93^I+%&M!
M`Y3=Z1)%`Y8$0`U`W>D&`8`864'=Z0@CS>D$`2E&(^H)`R+J"`(90R!&W>D$
M11!#"T9/ZDH1`I$D&-WI`@%=00`B`",P0\WI!",B&$_JF`,$DT7Q``,11D_J
MB'8:1@2;S>D2$HA&0^J)<P233^J9`P63W>D$(P`CWND:14_P``DR0P`A3^K8
M9A!&`"+-Z0(C1NI)%@_R+%/3Z0`CS>D&`1(93^I)%&M!`Y3=Z19%`Y8$0`U`
MW>D(`8`864'-Z00!W>D0(RE&($;=Z01%(^H+`R+J"@(90Q!#)!A/\``""T9/
MZD@1`I%=0=WI`@$`(\WI!"-/ZIH#,$,$DR(83^J*=D7Q``,`(1Q&$T8$FII&
MS>D6-``D0NJ+<@223^J;`@62W>D$(Z-&`"/>Z1Q%,D-/ZMIF1NI+%A!&`"+-
MZ0(C#_*`0]/I`"/-Z0@!$AE/ZDL4:T$#E-WI$D4#E@1`#4#=Z1`!@!A90=WI
M!B/-Z00!*48CZ@D#(NH(`AE#($;=Z01%$$,+1D_J2A$"D208W>D"`5U!`"(`
M(S!#S>D$(R(83^J8`P231?$``Q%&3^J(=AI&!)O-Z1(2B$9#ZHES!)-/ZID#
M!9/=Z00C`"/>Z1Y%3_``"3)#`"%/ZMAF$$8`(LWI`B-&ZDD6]J/3Z0`C$AE/
MZDD4:T$#E-WI%D7-Z1`!!$`-0-WI!@$#EH`864'=Z0@CS>D$`2E&(^H+`R+J
M"@(90R!&W>D$11!#"T9/ZD@1`I$D&-WI`@%=00`B`",P0\WI!",B&$_JF@,$
MDT7Q``-/ZHIV`"$<1A-&!)J:1LWI%C0`)$+JBW($DD_JFP(%DMWI!".C1@`C
MWND@13)#3^K:9D;J2Q801@`BS>D"(\VCT^D`(\WI!@$2&4_J2Q1K00.4W>D2
M10.6!$`-0-WI"`&`&%E!W>D0(\WI!`$I1B/J"0,BZ@@"&4,@1MWI!$400PM&
M3^I*$0*1)!C=Z0(!74$`(@`C,$/-Z00C(AA/ZI@#!)-%\0`#$49/ZHAV&D8$
MFXA&0^J)<P233^J9`P63S>D2$@`BD4;=Z00CWNDB10`C,D,`(4_JV&801@`B
MS>D"(T;J21:CH]/I`"/-Z0@!$AE/ZDD4:T$#E-WI%D4#E@1`#4`@1BE&W>D0
M1:0874'-Z01%W>D&-`U&3^I($0*1(^H*`R3J"P0:1B-&!$8=0Q1#W>D"`2M&
M(D;=Z01%,$-/ZHIVI!A/\``"74$`(\WI!",B&$_JF@,$DT7Q``,`)=[I)`$<
M1A-&!)J:1LWI$#0`)$+JBW($DD_JFP(%DLWI`D4`)=WI!",O1GJEU>D`14_J
MVF,R0P*3)!A/\``+34$61MWI$@'-Z01G`IXY0!!`3^I*$D;J2Q8"EMWI!F<V
M&6]!-$8]1MWI"&<FZ@@&)^H)!P9##T,P&4_JVV$#D4?K!0'=Z0)G`"0`)19#
M*T8B1D_JF`3-Z0(C@AE$ZHET3^J)<P.30?$``P.43^J(<0*1$$;-Z1(C3^J9
M!=WI`B-/\``(049&`2)#*T,`)!=&F$8`(\WI!GC-Z0(TPPX/\C@9V>D`B0*3
MWNDF-!/K"`-$ZPD$W>D&B1I&3_``"2-&`IQ$ZD$4`I3=Z1!%S>D0B03J"`0%
MZ@D%W>D(B1CK`@A)ZP,)W>D$(R+J"@(CZ@L#(D,K0QCK`@A/ZM%D2>L#"0.4
M0D9/ZHIT2T;=Z0*)2.H&"!+K"`9#\0`'3^J:`S)&0^J+<\WI"&=/ZIL&`I,=
M1@.6`"/=Z0)G#_*D#-SI`+PO0R9#U`ZZ1MWI!GBQ1D3J0Q1W0,WI!IH"E+A&
MWNDH9]WI$D4`)1;K"P;=Z02K1^L,!X3J"`0:ZP8*3^K39DOK!PL#EAKK!`9/
MZD(42_$`!]WI`JM*Z@0*A`<6ZPH(3^J0!D?Q``E&ZH%VCPC>Z2H!RD;!1LWI
M$II/\``*T49'Z@8+1NH$"MWI!F<`),WI!*O-Z0)%".``OYEY@EH`````H>O9
M;@````!/ZMAD`I2&Z@H&#_:,9=7I`$7=Z0BK)!C=Z1"\34$"F1OK!`N*Z@8*
M0>I)$4_JV60"D59&`Y1,ZP4,VD8:ZP8$W>D"JT_J2!!,\0`%`"%*Z@`*D`<4
MZPH&3^J2!$7Q``=$ZH-TLD:="+M&S>D0JT_P``O>Z2PC7T9$Z@`+`"#-Z0(!
M\0X"D0_V$&'1Z0`!1>H$#-WI!$6`&,WI"+Q9083J"P2"1@*;BT;=Z1(!!IE#
MZD<38$`"DW(!!$8:ZP$`2_$``0`9BT9/ZM=A`Y%+\0`!W>D"JTKJ`@I/ZHAR
M$.L*!$_JF`!!\0`%0.J)<$_JF0%`Z@()0>H`"D_P``A)1D_P``E21LWI`HG=
MZ0B:XP[-Z082HT8"DXGJ`0D/]GQ3T^D`(ZQ&WNDN`<WI$KQ/\``,@!AE1EE!
MS>D6`0298@$"F]WI$*M#ZDP3C$;=Z18!BNH)"@*3`",0ZPP`T$9!\0`!$.L(
M`(M&3^K580.12_$``=WI`JM*Z@(*L@<0ZPH(3^J6`$'Q``E`ZH=PN0A`Z@(*
MS>D0B4'J``L`(LWI`B/>Z3`!3^K88P*33_``"0_VZ$/3Z0`CW>D&9X`8S>D$
MJUE!S>D6`0B9ANH*!MWI$KQ/ZD@2`IN,1MWI%@&+Z@8+0^I)$Q#K#``"DT'Q
M``%>1H`93_```XM&3^K980.12_$``=WI`JM*Z@(*H@<0ZPH&3^J4`$'Q``=`
MZH5PLD8`)+M&S>D"-,WI$JM/\``+W>D$-%]&0.H""ZD(@^H+`T'J``S>Z3(!
M'$;S#@*3#_9,0]/I`"/-Z0B\@!A/ZD8264$"FX)&BT;=Z1`!!IE#ZD<38$`"
MDP1&&NL!`$OQ``$`&8M&3^K780.12_$``=WI`JM*Z@(*3^J(<A#K"@1/ZI@`
M0?$`!4#JB7!/ZID!0.H""4'J``I/\``(249/\``)4D;-Z0*)W>D(FN,.S>D&
M$J-&`I.)Z@$)#_;`,]/I`".L1M[I-`'-Z1"\3_``#(`8949900*;S>D6`6(!
M0^I,$P*3W>D2JP`C!)F*Z@D*C$;=Z18!T$80ZPP`0?$``1#K"`"+1D_JU6$#
MD4OQ``'=Z0*K2NH""K('$.L*"$_JE@!!\0`)0.J'<+D(0.H""D'J``L`(M[I
M-@'-Z0(C3^K88P*3#_8X,]/I`"/-Z02K@!C=Z1"\64'-Z18!")E/ZD@2W>D&
M9P*;C$;=Z18!ANH*!LWI$HD0ZPP`B^H&"T'Q``%/\``)0^I)$UY&`I.+1H`9
M3^K980.12_$``=WI`JL`(TKJ`@JB!Q#K"@9/ZI0`0?$`!T#JA7"R1@`DNT;-
MZ0(TS>D0JT_P``O=Z00T7T9`Z@(+J0B#Z@L#0>H`#-[I.`$<1O,.`I,/]I0C
MT^D`(\WI"+R`&$_J1A)900*;@D:+1MWI$@$&F4/J1Q-@0`*3!$8:ZP$`2_$`
M`0`9BT9/ZM=A`Y%+\0`!W>D"JTKJ`@I/ZHAR$.L*!$_JF`!!\0`%0.J)<$_J
MF0%`Z@()0>H`"J-&24:L1E)&S>D2O$_P``A/\``)S>D"B>,.W>D(FD_P``P"
MDV5&S>D&$HGJ`0D/]OP3T^D`(][I.@'=Z1"K@!A/ZD0264'-Z18!!)F*Z@D*
M`IO01D/J3!.,1MWI%@$"DQ#K#`!!\0`!$.L(`(M&3^K580.12_$``=WI`JM*
MZ@(*L@<0ZPH(3^J6`$'Q``E`ZH=PN0A`Z@(*0>H`"]WI!F=21M[I/`%;1E9`
MS>D$(Z\(#_9\$]/I`"-/ZMAJS>D0B4_P``F`&$KJ21I90<WI%@'=Z1(!")MP
M0,WX#*`&1MWI%@'`&$'Q``&"&4_JE`9/ZH1P1NJ%=M[I/D5!\0`#S>D((T_J
M2!,"D]WI`B,`(\WI`D5&Z@`$W>D$`4+J"@+=Z0BK1^H&!6!`S>D(1=WI`D4:
MZP(*!D8/]O0!T>D``4OQ``M21B08S>D2JTU!W>D0`0:93^K::G!`2NI#&F08
MS?@,H$7Q``4@&$7Q``'-Z08!40$"D=WI`@$-];A^3^J8!D_JF0=`Z@H`W>D&
MJT;JB79/ZHATWND`B1KK``I+\0`+#?6\?E!&1NH$"LWI`HE91D?J!@O=Z0)G
MS>D&JT_JT&@/]FP,W.D`O$_JDPG=Z0A%`"46ZPL&S>D6`4?K#`>$Z@H$LD8`
M(;Q&W>D29TCJ01AF0``DS>D"14P!!)T#E!KK!03-^`R`3/$`!4_P``RB1D0!
M&NL&"@*41?$`"]WI`D5E1D3J"`1/ZI((&NL$!DCJ@WA/ZH)SS?@,@`*3-$9+
M\0`'S>D29P`F`"?-Z01GW>D"9][I`",-]<!^1NH(!@_RS'S<Z0"\1^H)!QOK
M`@NQ1D_JU&8$EDSK`PRZ1@2;W>D&>$/J11,$DX?J"0?=Z18C")NX1H+J"`(;
MZP,&3^K58TSQ``<%D[(83^I$&T?Q``/-Z0(CW>D$(T_JD`C-Z1":2.J!>$+J
M"P+=Z0*K3^J1"88'&NL""D_P``!/\``!S>D"`4GJ"`%21DCJ!@!/\``#B$9/
MZM)A`I$'1@*>2_$`"]WI$`'-Z1:KS>D(>'A`WND`JT;J0Q[=Z1)G@>H(`0_R
M#'G9Z0")1D!/0,WI!&<8ZPH(!IY)ZPL)S?@(X%`!&.L&"$_JTV8#EDGQ``D$
MG@WUQ'X8ZP8*W>D"9TGQ``M/ZI0(!D-(ZH5X&NL&!LWX#(!+\0`'I`<"E#!&
MLD:[1MWI`F=/ZI4)S>D2JT_P``M&Z@@&64;>Z0!%1^H)!P_RD&S<Z0"\L4;&
M#KI&&^L$"]WI"'A&ZD$4$)Y,ZP4,!)3=Z19%A^H)!\WI`KRV1GQ`W>D"9T_J
M0!O-Z0::%NL.!J!&1_$`!\P.!906ZP@$1_$`!<WI`D7=Z01%#?7(?D_JD@B6
M!T3J"P3=Z0*K2.J#>$_JDPD:ZP0*3_``!4OQ``O-Z1:KWND`O%1&X@X-]<Q^
M0NI%$LWI`KQ(Z@8+W>D&9TGJ"`P/\NA:VND`FLWI$+R&Z@L&A^H,!]WI`KP;
MZPD+3.L*#-E&RD;=Z1*)B.H&"(GJ!PD`)@`GS>D"9VX!`Y8(GLWI!(D:ZP8(
M3^I$%@*63/$`"02>`Y(8ZP8*W>D"9TGQ``M/ZI`(%D-(ZH%X&NL&`LWX#(!+
M\0`#3^J1"19&DD:;1H,'`I/Q#M[I`",-]=!^S>D8JT_P``M?1@_R4%S<Z0"\
MS>D2(]WI`B-#Z@D#W>D0FD+J"`+-Z0@CB>H""=WI$B,2ZPL"0^L,`Y-&G$9!
MZD<3W>D6`0`A!)-S`8#J"0`"1@`@S>D"`0:9`I,;ZP$(3^I'$0.13^K78061
M3/$`"0.9&.L"`-WI!*M/\``(0>K680.1W>D"(TGQ``%/\``)S>D&B4+J"@)+
M1D_P``R21D)&S>D"(Z,(!I.K!P.3$.L*"`:;0?$`"4!&WND`JT/JA7,&DP.;
M24;-Z18!`"%#ZI0#`Y.K"`>3HP<"D]WI`HG$#MWI!B-$ZD$4#?74?DCJ`@A)
MZ@,)W>D((\WI$HF"Z@@"@^H)`P_R5$G9Z0")&.L*"$GK"PG"1LM&W>D8B8CJ
M`@B)Z@,)`"(`(\WI`B-+`0.3$)O-Z02)&NL#"$_J0!,"DTOQ``D$FP.4&.L#
M"MWI`B-)\0`+3^J6"")#2.J'>!KK`@3-^`R`2_$`!4_JEPDC1D_P``LL1LWI
M&#0`)!I&(T:T!P*4W>D"1<WI!+Q%Z@D%W>D2FD3J"`3>Z0!GK$:)Z@0)BNH,
M"J-&U0Y,1@25548/\J@ZVND`FLWI$+P9ZP8)!)Y*ZP<*R$9&ZD,7T48$E]WI
M%JL(GHKJ!`J+Z@4+S>D6JQCK!@I/ZM-F!986GDGQ``L#EU0!&NL&"`*42_$`
M"0`DW>D$JP`ES>D&16RNS>D(1=WI`D5$Z@H$HD:$"`:4C`<)E!CK"@H&G$GQ
M``M71D_JVFY$ZH%T!I0)G-A&S>D6>$_P``A$ZI`$"92,"($'!Y3!1@B1T$;=
MZ08!W>D(101##4/=Z1`!HT:L1M;I`$5`Z@L`W>D89T'J#`'-Z0:\!D`/0-WI
M$`%.ZDD1S>D$9T_JV6X`Z@L``I$/\L@KV^D`JP9&W>D$`1KK!`K-^`S@0.H&
M`!*>2^L%"P`D&NL&!D_P``5+\0`'S>D$9]WI!&<I1D_J2!J="#88($;-Z00!
M1_$`!]WI`@&4"$3J@W29!T#J"@`%D3`8!91'\0`!DP<`(@23%T;=Z00C@D:+
M1LWI$JM/\``*3_``"\WI`JO=Z0:\(D,K0P9&%$8-]=Q^'49:1LWI"$4B0V-&
M*T/U#@*5W>D61=[I``$=0%M&W>D(JQ1`S>D$10/J"@,0G4_J1AH<1H"CT^D`
M(Q(82T$01AE&`IM#ZD<3`I/=Z00C(D-$&4'Q``7Y#@.1`"``(<WI!`'=Z0(!
MI!A/ZI@!!)%`Z@H`1?$`!2`8!)Q%\0`!3^J9!43JB70%E0243^J(<LWI$`&`
M1MWI!`$C1D_P``IPK!!#&4/11D_JV&Z#1HQ&S>D"O-WI"*O4Z0`!W>D"15)&
M6T8B0RM#W>D21=WI`KP40%)&`NH+`@_R7!O;Z0"K'4#-Z1)%&NL`"@:=2^L!
M"T[J21,41@233^K98=WI$B,%D0`@`"'-Z08!W>D$`2)#&NL%!$_J2!I+\0`%
ML0BD&`:10.H*`$7Q``4@&`:<1?$``;T(1.J'=`:4!Y6R!R-&<JP&1LWI$@'4
MZ0"K`"3=Z08!]0X`)\WI!JL00]WI`KP90P`CS>D$-`256T9D1@-##$,:1B-&
MW>D01<WI$`$=0%M&`T#=Z0:K%$`KHM+I`!+-Z19%'$8$FQKK`0I+ZP(+")U#
MZD<>W>D6(\WX$.#Y#B)#!9$:ZP4$3_```$_P``%+\0`%"T:D&`)&S>D&(]WI
M!"-/ZD8:1?$`!4_JF`!"Z@H"0.J)<*(83^J)<P>31?$``P>03^J(=9!&!I7-
MZ0@C3^J9`=WI!B-TK$_P``I/ZMAN`D,+0]%&U.D``9-&G$;-Z02\3NI)'@K@
M`+^O\P"`H>O9;@````#<O!N/`````-WI$*O=Z01%S?@8X%)&6T8B0]WI!+PK
M0]WI$D440%)&`NH+`@_VF&O;Z0"K'4#-Z1)%&NL`"@*=2^L!"Q1&3^K98=WI
M$B,'D0`@`"'-Z0(!W>D&`2)#&NL%!$_J2!I+\0`%L0BD&`*10.H*`$7Q``4@
M&`*<1?$``;T(1.J'=`*4`Y6R!R-&=JP&1LWI$@'4Z0"K`"3=Z0(!]0X`)\WI
M!JL00]WI!+P90P`CS>D"-`*56T9D1@-##$,:1B-&W>D(1<WI"`$=0%M&`T`4
M0-WI!JL`(`_V[%+2Z0`2S>D611Q&`IL:ZP$*2^L""_D.0^I''MWI%B/-^`C@
M$)TB0P.1`"$:ZP4$"T9+\0`%I!@"1LWI!B/=Z0(C3^I&&D7Q``5/ZI@`0NH*
M`D#JB7"B&$_JB7,'DT7Q``,'D$_JB'4&E9!&S>D0(T_JF0'=Z08C>*Q/\``*
M3^K8;@)#"T/11M3I``&31IQ&S>D"O$[J21[=Z0BKW>D"1<WX&.!21EM&(D/=
MZ0*\*T/=Z1)%%$!21@+J"P(/]BQ;V^D`JQU`S>D211KK``H$G4OK`0L41D_J
MV6'=Z1(C!Y$`(``AS>D$`=WI!@$B0QKK!01/ZD@:2_$`!;$(I!@$D4#J"@!%
M\0`%(!@$G$7Q``&]"$3JAW0$E`65L@<C1GJL!D;-Z1(!U.D`JP`DW>D$`?4.
M`"?-Z0:K$$/=Z0*\&4,`(\WI!#0$E5M&9$8#0PQ#&D8C1MWI$$7-Z1`!'4!;
M1@-`W>D&JQ1`#_:`0M+I`!+-Z19%'$8$FQKK`0I+ZP(+")U#ZD<>W>D6(\WX
M$.#Y#B)#!9$:ZP4$3_```$_P``%+\0`%"T:D&`)&S>D&(]WI!"-/ZD8:1?$`
M!4_JF`!"Z@H"0.J)<*(83^J)<P>31?$``P>03^J(=0:5D$;-Z0@C3^J9`=WI
M!B-\K$_P``I/ZMAN`D,+0]%&U.D``9-&G$;-Z02\3NI)'MWI$*O=Z01%S?@8
MX`WU`'Y21EM&(D/=Z02\*T/=Z1)%%$!21@+J"P(/]K@[V^D`JQU`S>D211KK
M``H"G4OK`0L41D_JV6'=Z1(C!Y$`(``AS>D"`=WI!@$B0QKK!01/ZD@:2_$`
M!;$(I!@"D4#J"@!%\0`%(!@"G$7Q``&R!T3JAW0&1KT(`I0C1@.5?JS-Z1(!
MW>D"`0`G&4/4Z0`T$$,`(HQ&S>D&-``CS>D"(_0.W>D$(X-&`I3=Z0A%0NH+
M`$/J#`'-Z0B\!$`-0`+J"P`"F<WI%D4`(P)&0>I'$0*1W>D6`=WI!JL/]O@E
MU>D`11!#`"+-Z08C>P$'DQ";&NL$"DOK!0M/ZI@$&NL#"@>;2_$`"QKK``I#
MZM9C!Y-/ZM=C`Y-/ZD83!I/=Z08C2_$`"\WI$*M$ZHETW>D"JT_JB'!/ZID%
M3_``"4+J"@+=Z1"K&NL""DOQ``O-Z1"KT$9$Z@`*WND``47J!`M31D_JV&I<
M1LWI!C3-Z0(!2NI)&MWI"`$-]0)^&$,A0]WI$C0#0`Q`W>D&`<WI$C3=Z0@C
M`",/]D`EU>D`10)`W>D"`0`9:4$$1@U&W>D2`1!#`"+-Z0(C3^I)$P.3!)O-
M^`R@XAA/ZD@41?$``P*4$AA/ZI8$0_$``\WI!"/=Z0(C1.J'=-WI!+R]"$+J
M"@*P!QOK`@M/\``"3/$`#,WI$KQ/\``,7D9G1D3J``M%Z@0,WND`-`WU!'[-
MZ00T`"/-Z0(C]`[=Z08C`I3=Z1!%0NH+`$/J#`'-Z1"\!$`-0`+J"P`"F<WI
M%D4`(P)&0>I'$0*1W>D6`=WI!*L/]G@5U>D`11!#`"+-Z00C>P$%DPB;&NL$
M"DOK!0M/ZI@$&NL#"@6;2_$`"QKK``I#ZM9C!9-/ZM=C`Y-/ZD83!)-+\0`+
MW>D$(\WI"*M$ZHETW>D"JT_JF05/ZHAP3_``"4+J"@+=Z0BK&NL""M[I`!)+
M\0`+S>D$J]!&1>H$"\WI`A)$Z@`*W>D0`5Q&4T;-Z0@T&$/=Z1(TW>D(14_J
MV&H#0$KJ21H-]09^&$;=Z1`C(D`K0`_VQ`75Z0!%S>D2(]WI`B,2&6M!%$8=
M1MWI$B,`(P)#$$8`(LWI`B-/ZDD3`Y,&F\WX#*#B&$_J2!1%\0`#`I02&$_J
ME@1#\0`#S>D&(]WI`B-$ZH=TW>D&O+T(0NH*`K`'&^L""T_P``),\0`,S>D6
MO$_P``Q>1F=&1.H`"T7J!`S>Z0`TS>D2O`WU"'[-Z08T`"/-Z0(C]`[=Z0@C
M`I3=Z01%0NH+`$/J#`$`(P1`#4`"Z@L``IG-Z01%`D9!ZD<1`I'=Z00!#_+\
M==7I`$7=Z0:K$$,`(LWI!"-[`063$)L:ZP0*2^L%"T_JF`0:ZP,*!9M+\0`+
M&NL`"D/JUF,%DT_JUV,#DT_J1A,$D]WI!"-+\0`+S>D&JT3JB73=Z0*K3^J(
M<$_JF05/\``)0NH*`MWI!JL:ZP(*2_$`"\WI!*O01D3J``K>Z0`!1>H$"U-&
M3^K8:EQ&S>D&-,WI`@%*ZDD:W>D2`0WU"GX80R%#W>D6-`-`#$#=Z08!S>D0
M--WI$B,`(P_R/'75Z0!%`D#=Z0(!`!EI001&#4;=Z1`!$$,`(LWI`B-/ZDD3
M`Y,(F\WX#*#B&$_J2!1%\0`#`I02&$_JE@1#\0`#S>D((]WI`B-$ZH=TW>D(
MO+T(0NH*`K`'&^L""T_P``),\0`,S>D6O$_P``Q>1F=&1.H`"T7J!`S>Z0`T
M#?4,?LWI"#0`(\WI`B/T#MWI!B,"E-WI!$5"Z@L`0^H,`<WI$+P$0`U``NH+
M``*9S>D$10`C`D9!ZD<1`I'=Z00!W>D(JP_R>&75Z0!%$$,`(LWI!"-[`063
M$IL:ZP0*2^L%"T_JF`0:ZP,*!9M+\0`+&NL`"D/JUF,%DT_JUV,#DT_J1A,$
MD]WI!"-+\0`+S>D(JT3JB73=Z0*K3^J9!4_JB'!/\``)0NH*`MWI"*L:ZP(*
MWND`$DOQ``O-Z02KT$9%Z@0+S>D"$D3J``K=Z1`!7$931LWI"#080]WI%C3=
MZ0A%3^K8:@-`2NI)&@WU#GX81MWI$",B0"M`#_+`5=7I`$7-Z1(CW>D"(Q(9
M:T$41AU&W>D2(P`C`D,01@`BS>D"(T_J21,#DP:;S?@,H.(83^I(%$7Q``,"
ME!(83^J6!$/Q``/-Z08CW>D"(T3JAW3=Z0:\O0A"Z@H"L`<;ZP(+3_```DSQ
M``S-Z1*\3_``#%Y&9T9$Z@`+1>H$#-[I`#3-Z0:\#?40?LWI%C0`(\WI`B/T
M#MWI"","E-WI!$5"Z@L`0^H,`0`C!$`-0`+J"P`"F<WI!$4"1D'J1Q$"D=WI
M!`$/\OA%U>D`1=WI%JL00P`BS>D$(WL!!9,0FQKK!`I+ZP4+3^J8!!KK`PH%
MFTOQ``L:ZP`*0^K68P633^K78P.33^I&$P232_$`"]WI!"/-Z1"K1.J)=-WI
M`JM/ZHAP3^J9!4_P``E"Z@H"W>D0JQKK`@I+\0`+S>D0J]!&1.H`"M[I``%%
MZ@0+4T9/ZMAJ7$9*ZDD:S>D"`0WU$G[=Z08!S>D$-!A#(4/=Z1(T`T`,0-WI
M!`'-Z1(TW>D&(P`C#_(\1=7I`$4"0-WI`@$`&6E!!$8-1MWI$@$00P`BS>D"
M(T_J21,#DPB;S?@,H.(83^I(%$7Q``,"E!(83^J6!$/Q``/-Z0@CW>D"(T3J
MAW3=Z0B\O0A"Z@H"L`<;ZP(+WND`(TSQ``S-Z1*\3_``#%Y&9T9$Z@`+1>H$
M#/`.7$9`ZD<094;=Z02\S>D(10WU%'Y+Z@0+3.H%#`.07$;=Z1"K"NH$"@OJ
M#`O=Z01%3^J9!<WI$*O=Z0BK!.H*!`_R?#O;Z0"K&NL""DOK`PO=Z1`C!IL4
M0QKK`PI/ZD83`I-+\0`+W>D"(QKK!`I+\0`+3^J8!`)#1.J)=!KK`@`#E$OQ
M``$`(PI&`4;-Z1823^J(<0*1`D;=Z0(!3^K2:MWI"(E*ZD,:($,I0XCJ``C>
MZ0!%S>D&`4_JEPG"H='I``'-^`R@)!A-0=WI$@$$F8#J"`!/ZI8(9!A(ZH=X
M1?$`!2`81?$``<WI!`%1`0*1W>D"`9:OW>D$O+0'0.H*`$CJ!`8;ZP`+3/$`
M#%A&U^D`JTGJ"`?=Z0:)S>D09V%&B.H&"*BFUND`5LWI$@'$#@`A&NL%"D3J
M010"E-WI%D5+ZP8+")X`)83J"`1/ZI,)H$8`),WI!$5,`064S`X#E+9&!9P:
MZPX&2_$`!PWU&GY$ZM!D!906ZP@$3^J2"$?Q``7=Z0)GHD9$`024JT;=Z01%
M2.J#>)BK`"4F0QKK!@I/ZH)V2_$`"\WI"*M41D_P``M/\``*S>D"JTCJ!@I)
MZ@@+T^D`(^8.T4;:1@_R^!S<Z0"\`I8;ZP(+W>D0>$SK`PP"F\WI!)J'Z@D'
M0^I%$P*3W>D2([A&!IM/ZI$)@NH(`D_JD`@;ZP,&2.J!>$SQ``>R&$_J@';>
MZ0`!3^K58P.31_$``\WI!B/=Z0(C3^I$&\WI`@%(Z@8`2>H(`=WI!'A"Z@L"
MW>D&JT=`S>D&`=WI`@$:ZP(*N$9;I]?I`&=+\0`+4D:`&<WI$JMY00`C!D9/
MZMIJ#T;=Z0@!$)E*ZD,:@.H(`,WX#*!V&$_JE`A'\0`',!A'\0`!S>D(`5$!
M`I'=Z0(!2.J%>$_JE0FF!T#J"@#=Z0BK#?4<?AKK``I+\0`+WND`15!&3_``
M"EE&3_``"\WI`JM(Z@8*2>H("]WI!GC&#@*6A^H*!\WI$`$`(<WI"*NX1C.G
MU^D`9T_J0!M/ZI,)-AD"G&]!S>D69P2>1.I!%`*4W>D21;9&W>D69X3J"`06
MZPX&#?4@?J!&1_$`!\P.`Y06ZP@$3^J2"$?Q``7-Z01%W>D"14CJ@WB6!TGJ
M"`Q$Z@L$W>D$JYZK`"4:ZP0*2_$`"\WI$JM41D_P``M/\``*S>D"JTCJ!@O=
MZ0AXT^D`(^8.A^H+!P*6V4;B1KA&#*?7Z0!GS>D$FD_JD0FV&$_J1!M?00*;
M0^I%$P*3W>D0(PK@`+^O\P"`W+P;CP````#6P6+*``````:;@NH(`D_JD`CV
M&$CJ@7A'\0`'LAA/ZH!VWND``4_JU6,#DT?Q``/-Z08CW>D"(P`CS>D"`4CJ
M!@!)Z@@!W>D$>$+J"P+=Z0:K1T#-Z08!W>D"`1KK`@JX1@_V5`?7Z0!G2_$`
M"U)&@!G-Z1"K>4%/ZMIJ!D9*ZD,:#T;=Z1(!")D-]2)^@.H(`,WX#*!V&$_J
ME`A'\0`',!A'\0`!S>D(`5$!`I'=Z0(!2.J%>$_JE0FF!T#J"@#=Z0BKWND`
M11KK``I+\0`+4$9/\``*649/\``+S>D2`0`AS>D"JTCJ!@I)Z@@+Q@X"ED_J
MDPG=Z09XS>D(JT_J0!N'Z@H'N$8/\JQWU^D`9S89`IQO0<WI%F<$GD3J010"
ME-WI$$6V1MWI%F>$Z@@$%NL.!@WU)GZ@1D?Q``?,#@.4%NL(!$_JD@A'\0`%
MS>D$1=WI`D5(ZH-XE@=)Z@@,1.H+!-WI!*NDJP`E&NL$"DOQ``O-Z1"K5$9/
M\``+3_``"LWI`JM(Z@8+W>D(>-/I`"/F#H?J"P<"EME&XD:X1@_R%'?7Z0!G
MS>D$FD_JD0FV&$_J1!M?00*;0^I%$P*3W>D2(P:;@NH(`D_JD`CV&$CJ@7A'
M\0`'LAA/ZH!VWND``4_JU6,#DT?Q``/-Z08CW>D"(P`CS>D"`4CJ!@!)Z@@!
MW>D$>$+J"P+=Z0:K1T#-Z08!W>D"`1KK`@JX1@_RF&?7Z0!G2_$`"\WI$JN`
M&5)&>4%/ZMIJ!D9*ZD,:#T;=Z1`!")E/ZI4)@.H(`,WX#*!V&$_JE`A'\0`'
M,!A'\0`!S>D(`5$!`I'=Z0(!2.J%>*8'#?4H?D#J"@#=Z0BKWND`11KK``I+
M\0`+4$9/\``*649/\``+S>D"JTCJ!@I)Z@@+W>D&>,8.`I:'Z@H'S>D0`0`A
MS>D(J[A&#_+X5]?I`&=/ZD`;3^J3"389`IQO0<WI%F<$GD3J010"E-WI$D6V
M1MWI%F>$Z@@$%NL.!@WU+'Z@1D?Q``?,#@.4%NL(!$_JD@A'\0`%S>D$1=WI
M`D5(ZH-XE@=)Z@@,1.H+!-WI!*NJJP`E&NL$"DOQ``O-Z1*K5$9/\``+3_``
M"LWI`JM(Z@8+W>D(>-/I`"/F#H?J"P<"EME&XD:X1@_R6%?7Z0!GS>D$FD_J
MD0FV&$_J1!M?00*;0^I%$P*3W>D0(P:;@NH(`D_JD`CV&$CJ@7A'\0`'LAA/
MZM5C3^J`=@.31_$``\WI!B/>Z0`!#?4N?MWI`B,`(\WI`@%(Z@8`2>H(`=WI
M!'A"Z@L"W>D&JT=`S>D&`=WI`@$:ZP(*N$8/\MA'U^D`9TOQ``M21H`9S>D0
MJWE!3^K::@9&2NI#&@]&W>D2`0B93^J5"8#J"`#-^`R@=AA/ZI0(1_$`!S`8
M1_$``<WI"`%1`0*1W>D"`4CJA7BF!][I`$5`Z@H`W>D(JQKK``I+\0`+4$9/
M\``*649/\``+S>D"JTCJ!@I)Z@@+W>D&>,8.`I:'Z@H'S>D2`0`AS>D(J[A&
M#_(\1]?I`&=/ZD`;3^J3"389`IQO0<WI%F<$GD3J010"E-WI$$6V1MWI%F>$
MZ@@$%NL.!@WU,GZ@1D?Q``?,#@.4%NL(!$_JD@A'\0`%S>D$1=WI`D5(ZH-X
ML*N6!T3J"P3=Z02KT^D`(TGJ"`P:ZP0*3_``!4OQ``O-Z1"K5$9/\``+3_``
M"LWI`JM(Z@8+W>D(>.8.`I:'Z@L'V4;B1LWI!)JX1N:GU^D`9T_JD0E/ZD0;
MMAA?00*;0^I%$P*3W>D2(P:;@NH(`D_JD`CV&$CJ@7A'\0`'LAA/ZH!VWND`
M`4_JU6,#DT?Q``/-Z08CW>D"(P`CS>D"`4CJ!@!)Z@@!W>D$>$+J"P+=Z0:K
M1T#-Z08!W>D"`1KK`@JX1LBGU^D`9TOQ``M21H`9S>D2JWE!3^K::@9&2NI#
M&@]&W>D0`0B93^J5"8#J"`#-^`R@=AA/ZI0(1_$`!S`81_$``<WI"`%1`0*1
MW>D"`4CJA7BF!PWU-'Y`Z@H`W>D(J][I`$4:ZP`*2_$`"U!&3_``"EE&3_``
M"\WI`JM(Z@8*2>H("]WI!GC&#@*6A^H*!\WI%@$`(<WI"*NX1J&GU^D`9T_J
M0!M/ZI,)-AD"G&]!S>D09T3J010"E-WI$D4$GH3J"`2V1MWI$&>@1LP.%NL.
M!@.41_$`!Q;K"`1'\0`%S>D$1=WI`D5/ZI((2.J#>)8'1.H+!-WI!*M)Z@@,
MMJL:ZP0*3_``!4OQ``O-Z02K5$9/\``+3_``"LWI`JM(Z@8+W>D(>-/I`"/F
M#H?J"P<"EME&3^I$&[A&>:?7Z0!GXD;-Z1":MA@-]3A^7T$"FT_JD0E#ZD43
M`I/=Z18C!IN"Z@@"3^J0"/883^K58T?Q``<#D[(82.J!>$?Q``/-Z08CW>D"
M(X8'`"-)Z@@,0NH+`MWI!JL:ZP(*2_$`"\WI$JM21DCJ!@O1#M[I`&</\G`9
MV>D`B4'J0Q$"D4_J2AH(F1;K"`;-Z0:\#?4Z?A;K`0C=Z08!W>D09]D.`Y%/
MZI4+1D#=Z00!<$"F!QCK``"`1MWI`@$`(4#J"@",1ACK``A/ZI0*2NJ%>@`D
M0$8`)=[I`(G!#LWI`D7-Z01%2^H*!0*184:#1DD!!9%*Z@8$/*'1Z0`!)D;-
MZ19%$.L(`-WI$GA<1F5&@4;=Z08!$)E&0,WI"$49ZP$(Z0XP1@*>1T`#D4;J
M3!X%GLWX".!A`:9&&.L'!$;JVV8$D066HT;=Z0*:E@C=Z01%1NJ#=I`'`"-$
MZ@D$&^L$"-WI`*L:G$;J``L:ZP@*W>D4B=WI#&=/\``)4D;$Z0`C!IN]F!CK
M`PC=Z0@CQ.D(B;887T$;F\WI`&?=Z0Y6&6@6F^T8W>D*(T;Q``;-Z0)6W>D`
M9Q+K"P(`)XA"DD9/\``#Q.D"9U)&W>D"14_P``4:G\?I!D7'Z00C`]$-]3]]
MO>CPC_SW2.K6P6+*```````H/-`MZ?A#2_(X$\#R`@/3^`"0N?$`#R[0!7@]
M+1B_`"T4OP$E`"45T=GX`$!\L8!&#T9.1BI&048@1OSW3.L0N6-=/2L/T%;X
M!$\`+/+1($:]Z/B#!485^`$_/2L8OP`K^=$M&N#GR>L&!F@<($2V$#Y@O>CX
M@TA&O>CX@W!'\+5+\D`6P/("!H.P,VA+\C@7!4;`\@('`9-I1BA&__>O_ZBQ
M`)PY:`'KA`-::$'X)"``*O'0!#-3^`0O0_@$+``J^=%I1BA&__>:_P`HZ=$!
MFC-HFD(!T0.P\+W\]]3I+>GP3TOR0!4+>,#R`@4,1BIH/2N%L`B_`30&1@.2
M($;\]T+J`JD'1C!&__=Y_X)&`"A7T/SW..J'0DK9`IM+\C@9P/(""4_J@P@Q
M>#TI&+\`*12_`2$`(0?0,481^`$_/2L8OP`K^=&)&[@<V?@`D`A$2_(X%_SW
M].G`\@('2?@(```H;M`Z:'$<`I@S>%+X(```*QB_/2L#<`G00AP1^`$[$$8`
M*QB_/2L"^`$[]M$"1CTC`W`4^`$[`O@!/P`K^=$`(`.:*VB:0D[1!;"]Z/"/
M"O'_,!3X`3L`^`$_`"OYT>[G2_(X&<#R`@G9^`"PV_@``)BS6T93^`0O"O$!
M"@`J^=$*\0(!B0!+\F@3P/("`QIH@K%81OSW6NG)^````+-/ZHH(`T8*\0$"
M`"%#^"(0S?@(H(CG"$8!(AI@_/>0Z0&0<+%/ZHH(649"1OSW\.C=^`3`8T;)
M^`#`Y.>"1@@ATN=/\/\PK.?\]Q[I`+\MZ?!!2_)`%<#R`@6>L"MH'9,0L0-X
M!T8SN1V:*VB:0E+1'K"]Z/"!_/=6Z09&`"CST#!&_/<(ZIBSPGPN*C?0`/$3
M!#A&_/=XZ8!&($;\]W3I0$0",/SW3.E&]A0#P/(!`T_P_S(!(0&4`)>`1OSW
M@NE!1@*J`R#\]P#J`3!`1@70!IL#]'!#L_6`3QG0_/?BZ$!&_/>:Z#!&_/?6
MZ0`HR]$P1OSW".HX1OSWKNBTYP)]`"J]T"XJPM%"?0`JN-"^Y__WG?_DY_SW
MMNAPM4OR2!3`\@($(&C\]_3IT/B`,"!H7FC\]^[ID/AE4"!H_/?JZ07P?P5#
M:!N*P_,(`T7JPQ5U@"!H_/?>Z=#X@#`@:%UH_/?8Z4;V)#$`(L#R`0'\]QSI
MZ&$@:/SWS.G0^(`P(&A=:/SWQNG0^.`T(&@K8OSWP.G0^(`P(&A=:/SWNNG0
M^/PP*[$@:/SWM.G0^/PP&V]K8@`E(&C\]ZSIT/B`,"!H6VB=8OSWING0^(`P
M(&A;:)UA_/>>Z=#X@#`@:%QH_/>8Z=#X&#+C8G"].+5+\D@4P/("!`5&(&C\
M]XSI*48`]81R`R#\]WKI"+$`(#B](&C\]X#IT/@8,0/T<$.S]8!/"=`@:/SW
M=NG0^!@Q`_1P0[/U($_IT2A&`B'\]Q3IL/J`\$`).+WPM4OR0!2M]8!=P/("
M!(.P(V@-]8!5!D8$-4;V'``/1L#R`0`!J4#V_W(K8/SW+N@`*"/=11X!JUI=
MZK$%1BI&+R$!J/SWYNC`L4OR2!/`\@(#&&C\]SKI*T8!JC%&_/?^Z`WU@%,$
M,QIH(VB:0A'1#?6`70.P\+T`+>#12_)($\#R`@,8:/SW(NDZ1C%&^_?X[^;G
M^_?4[TOR2!/`\@(#$+48:/SW$NE&\IAS0?+L4D;V+`'`\@$#P/(!`L#R`0&]
MZ!!`_/=NN!"U2_)(%,#R`@2"L"!H_/?ZZ/_WW?\@:/SW].A&]B0S1O+I,D;V
M2`'`\@$#P/(!`@"3P/(!`0`D`93\]X+H`K`0O0"_<+5+\D`4K?4`7<#R`@2&
ML"-H#?4`4A0R$V#\]P#H1O9L`D;V8`/`\@$"P/(!`P&2`2%!\@$"`)`#J/SW
M&N@`*"+;#?6`40.H3_2`4A`Q^_>8[P4>&-MH'/OWR.\&1JBQ#?6`42I&$#'[
M]SKO,$8`(W-5#?4`4Q0S&F@C:)I"!M$-]0!=!K!PO0`@\N?QY_OW4N\`O__W
MM+\MZ?!/2_)`%JWU@%W`\@(&A[`S:`WU@%($1A0R1O9T``]&P/(!``2I$V#_
M]_/\+R$%1B!&^_>^[Z"Q1O:``"%&P/(!`/_W5OT@1@WU@%,4,QIH,VB:0D#P
MD(`-]8!=!["]Z/"/($;[]YKO1O:0`<#R`0&!1CA&_/<(Z()&`"C<T$;V<`=&
M]IP(P/(!!\#R`0B:^``P`"L(O[I&+;%11BA&^_>H[@`H3-!01OOW>.\*ZP`#
M$_@!/"\K"-%#'@`A4T09<`$X$_@!+2\J^=`)\0$#&$2P]8!?L-I&]I0#2_)(
M&T_T@%(!(<#R`0,"E,WX!(`%J,WX`*#`\@(+^_=N[]OX``#\]Q+H!:D`]81R
M`R#[]^CO4+G;^```_/<&Z-#X&#$#]'!#L_4`3Q;01O:0`0`@P/(!`?OWJ.^"
M1KKQ``^GT7OG1O:0`<#R`0'[]Y[O@D:Z\0`/G-%PYP$A!:C[]X[O`"CBT4;V
M@``%J<#R`0#_]\'\!:C[]S[O9^?[]Y#N`+\#>#NQ0APO*PB_$$82^`$[`"OX
MT7!'`+\XM8BS!7@$1G6S^_?\[@$X(QB<0@S2(EPO*B_16AX"X!EX+RDJT:)"
M$T8"\?\R]]&<0A?0`3L"X!%X+RD$T9Q"&D8#\?\S]],2&Y,<L_6`7Q+8`3(A
M1D_T@%,22/OW3.X02#B]+RT4T0(@^_>H[@-&$+$N(AJ`.+T`(#B]6AX"X!EX
M+RG6T)1"$T8"\?\R]]/.YT;VG`#`\@$`O>@X0/OWV[X`OVRQ`@#PM8VP7TT"
MK$OR0!;`\@(&#\TW:`_$#\T+ERUH#\1&]J``P/(!`"6`__<4_$;VK`#`\@$`
M__<._$;VM`#`\@$`__<(_$;VP`#`\@$`__<"_$;VR`#`\@$`__?\^T;VV`#`
M\@$`__?V^T;V=`#`\@$`__?P^T;VY`#`\@$`__?J^T;V\`#`\@$`__?D^T;V
M_`#`\@$`__?>^T;V@`#`\@$`__?8^T;V"!#`\@$`__?2^T;V%!#`\@$`__?,
M^T;V(!`!J<#R`0#_]X7[`48HL4;V\`#`\@$`__?M^T;V-!`!J<#R`0#_]W;[
M`48HL4;V2!#`\@$`__?>^T;V5!`!J<#R`0#_]V?[`4:HL4;V=`#`\@$`__?/
M^T;VA!%&]L@`P/(!`<#R`0#_]\7["YHS:)I")=$-L/"]1O9D$`&IP/(!`/_W
M2/L!1C"Q1O;D`,#R`0#_][#[W^=&]G@1"B+`\@$!#?$9`/OWHNX`*-311O;D
M``WQ(P'`\@$`__><^\OG^_=N[0"_I&<!`#"U2_)`%$OR+!7`\@($(VC`\@(%
M@[`H:`&30QP%T`&:(VB:0A+1`[`PO4;VY`!I1L#R`0#_]PK[,+$`>``H&+\P
M*!2_`2``("A@Z.?[]T+M"+7[]_[L^_?P[`"Q`&@(O2WI\$<'1BQ,CK`&K4OR
M0!C`\@((#\S8^`!@#\64Z`<`!IP-EH7H!P#LL4;VD`D&K<#R`0D&X#E&^_?"
M[-BQ5?@$3X2Q!:D@1O_WT/H&1A"Q`W@`*^_1($8Y1O_W-_M5^`1/`"SNT0V:
MV/@`,)I"(-$.L+WH\(<X1OOW?.V"1C!&^_=X[5!$`C#[]U#M1O:4`P*6P/(!
M`\WX!)!/\/\R`)<!(8)&^_>$[5%&($;_]P[[Q>?[]^#L`+_(9P$`+>GP3P5&
MQ$RM]0%-D;!+\D`3!/$,#!*OE.@'`,#R`@/3^`"`#?%@#@F3)#05K@WU`4F'
MZ`<`"?$\";SH#P#)^`"`KN@/`)SH`P".Z`,`E.@'`(;H!P!&]G0`$:G`\@$`
M__=F^B"Q`W@$1@`K0/"&@?_W8/^`1@`H4]!`1OOW'.U```$P^_?T[)CX`"`&
M1@1&>K%&]I`3`)(@1D_P_S+`\@$#`2'[]R;M&/@!+P(T`"KOT1B8&*P8N13@
M5/@$#XBQ$:G_]S7Z@$8`*/;0`W@`*_/0__<C_``H[]!`1OOW&.V!1G"[$IQ4
MLR-X3_`!"#NY)>!7^"A`%+,C>`CQ`0CSL2!&__<+_``H\]`@1OOW`.T`*.[0
M@484X/OW^NP`*$#P.8%6^`0+`"@`\"Z!$:G_]__Y`"CUT`-X`"ORT.SG3_``
M"4A&1O:<"_OWMNS`\@$+!$8P1OOWL.P@1`#R!$0@1OOWANQ&]J021O:8$\#R
M`0+`\@$#`I(!(4_P_S(#ELWX`)#-^`2P@D;[][3L4$9/].!Q^_?,[`$P*]!+
M\D@6P/("!C!H^_=.[5%&`/6$<@,@^_<\[:"S2_)0$4;V+"+`\@(!*V@(:,#R
M`0+-^`"@`2'[]]#L`"`-]0%#/#,::`F;&VB:0D#PKX(-]0%-$;"]Z/"/^_=Z
M[`%H$2G.T$OR4!!&]JP2P/("`"MH`&C`\@$"`9$!(<WX`*#[]ZSL`"#:YS!H
M^_<0[=#X&#$#]'!#L_6`3\#1,&C[]P;MT/@@<?OW>NN'0K?1,&C[]_SLT/@8
M,</S"`.S]>!_K=$@1OOW".P1J01&1O9X,,#R`0#_]V#Y`"@`\&:"+FC[]TKL
M`48P1O_W3/P&1@`H`/!;@C!&^_<4[`,H!T81W00X1O;H$3!$P/(!`?OW-.M`
MN00O`/#A@3=$%_@%/"\K`/#;@?_W$OXPN0%&,$;[]\[K#)``*&/11O:$$4;V
MY`#`\@$!P/(!`/_WEOE&]B0W^_?:ZT;V""/`\@$'S?@$L`.7P/(!`\WX`*!/
M\/\R`2&X1@`F5T8"D"!&^_?PZQG@Y&<!`/OWY.L#:!$K&M'[][SK1O88(P$V
MS?@0@`.6*D;-^`2PP/(!`P"7`2$"D"!&^_?4ZT_TX'$@1OOW[.M#'`5&W]"Z
M1E!&^_?TZD;V=``A1L#R`0#_]T_Y($;_]^;]($8LY__WXOT@1OOWQNLFYT;V
MB!@-(,#R`0AWYH!&<.9/\/\S;_`1`@(E`)7[]T;K3ZD&(@R8^_>\ZIWX/#$C
MN9WX/3%#*P#PB($`)0`B`",`E0R8^_<RZ]^CT^D`(^"AT>D``>"GU^D`9\WI
M(",LJSR5S>DB`1U&W:'1Z0`!WJ/3Z0`CS>DD9\WI'@'-Z28C`"(`(PV4S>DH
M(\WI*B/-^#B@S?@\L$_T`$)/J0R8^_>`Z@0>=-W=Z2@C3^K$"D_P``DF1AKK
M`@B910B_D$5/ZN1WW>DJ(P+2`3)#\0`#<0\\F$'JQP$&D7D/!Y'=Z09GS>DH
MB;887T$R1CM&S>DJ(P`H2M#`\4`('JN@10#Q.``81$^IJ+^@1D)&^_=HZCR;
M0T0\DT`KOM%/JQZHR.L$!)A$^_<]_3\L)]VD\4`#"/%`#`J3G`D$\0()".N)
M&:SQ0`:N1C!H$#96^`P<=T96^`@L#O$0#E;X!#QF10_'\=$>J/OW'?T&\4`,
MS$7GT6,<"IH(ZX,8HNN$%$%&2",B1BA&^_>"ZCR4A><-]9YXRN<,J)#H$0S[
M]X#K'JLHG8`@*I[%\\4"F1A3'#@K@?@X``+Q.0``\Z^`'JO"\3<"&$0`(?OW
M]NH>J#(.,PR-^.M@C?CO4#8*C?CH(`WUB'B-^.DP*PZ-^.I@#?(/%XWX[#`K
M#"T*C?CM,(WX[E#[]]#\W?AXP#^NW?B`X"*8))E/ZAQ%)IM/ZAQBC?C_P$_J
M'"R-^/U014:-^/[`3^H>;(WX`^&-^`#!3^H>3(WX!P%/ZAXNC?@+$8WX`N%/
MZA!NC?@/,8WX!.%/ZA!.C?C\(``*C?@%X4_J$6Z-^`8!"`R-^`CA"0I/ZA-N
MC?@)`8WX`<$8#(WX"A$;"HWX#.&-^`T!C?@.,0'@%O@!+T;VD!,`DBA&P/(!
M`T_P_S(!(?OW7NJ^0@7Q`@7NT4;V)#%&]O@3S?@(@,#R`0'-^`2P`"4#D<#R
M`0/-^`"@3_#_,@$A($:(^"A0^_="ZG7F;6@`+3_T(:XH1OOW'.H#*'_V&ZX$
M.$;V\!$H1,#R`0'[]S[I`"@(ORY&#N8>J\+Q/P(81``A^_=&ZAZH^_<[_``C
M+),MDRZ3+Y,PDS&3,I,SDS23-9,VDS>3.),YDSWGG?@^,4$K?_1SKIWX/S%#
M*W_T;JZ=^$`Q2"M_]&FNG?A!,44K?_1DK@"53_#_,PR=;_`Y`BA&^_>4Z4^I
M*$8I(OOW"NE&]B0R1O;X$T^IP/(!`@*1`Y+`\@$#S?@$L$_P_S+-^`"@`2$@
M1OOWVND-YBYHHN7[]SCI`+^O\P"`B:O-[P````#^W+J8`````'94,A``````
M`2-%9P````#PX=+#`````"WI\$]+\D`3A;#`\@(#2_)(%P&3P/("!QMH.&@#
MD_OW5NH!(P*I@/AA,$;VR`#`\@$`_O?!_ABQ`W@Q*P#PV8#_]]#Z.&A,\F`F
M^_=`ZD;V@"'`\@$!"R,!(OOW6ND`*`#PS(#`\@(&`FE6^/0\`2O2^!B`.]U+
M\D@9`"7`\@()`20DX`)H3_2`8U;X\`S`\B`#D6A0^"2P"T"S]8!O"+\1:0K0
MV?@``/OW$.K:^``0`B,`(OOW]N@!1EA&^_=LZ%;X]#R`N0$T`36C0@S=.&C[
M]_SI`",J1D%&^_>NZ8)&`"C/T5;X]#Q:'JI"<M`X:$OR2!3[]^KI1O:((<#R
M`0$#(P$BP/("!/OW`ND%1H"Q(&C[]]SI*VE&]HPBP/(!`AEH^_>NZ"MI&VB;
M:%L"`/&W@#AH2_)(%/OWR.E&]I0AP/(!`0,C`2+`\@($^_?@Z`5&F+%&]H``
M`JG`\@$`_O<K_H!&(&BX\0`/`/"/@/OWKNDK:4)&&6C[]X+H.&A+\D@9^_>D
MZ0`B`JE,\F`DP/(""<#R`@0#1D;V=`#`\@$`@_AA(/[W"/Z`1D;X[`Q`LT_T
MX''[]_[H0AP#1A$H&+\!*GW8`9L#FAMHFD)VT06PO>CPCP$KBMT!)#AH`33[
M]W;I04;Z]_SO5OCT/*-"]-Q]YT-X`"L_]"6O(>?`\@(&=>=4^/`,__<_^T3X
M[`P`*$[0*FE/](!CP/(@`Q)HD6@+0+/U@&\(OQ!I"=#9^```^_=,Z2EI0D8"
M(PEH^_<RZ%;X\$PA1OKWV.\K:29H3_2`8L#R(`(<:*-H&D"R]8!O"+\B:8!&
M"=`X:/OW,.DI:0`B`B,):/OW%N@"1D;VO"!#1C%&P/(!`/OW?NC[]Q[I5OCP
M+"MI$6@8:/[WL?]MYR!H^_<4Z2MI&6C[]YSH0.=&]I@@P/(!`/OW9NCZ]\#O
M5/CP'$;VY"!"1L#R`0`):/OW6N@XM05&__<P^0-X!$8[L4(<+RL(OQ1&$O@!
M.P`K^-'_]SOZ`"@8OP`M"M`K>$.Q1O:D$2!&P/(!`?KW/N^$0@#0.+TH1KWH
M.$#^]W2^$+5+\D@4P/("!"!H^_?.Z$_P_S'Z]\CO(&C[]\CH1?*]0<#R`0$`
M(KWH$$#[]Y*X`DM[1`.Q&VCZ]WB_ZDD!`"WI^$,'1@Q.B$8,39%&?D3Z]_SN
M?41V&[80"M`$/0`D`315^`0_.$9!1DI&F$>T0O;1O>CX@P"_GD<!`)1'`0!P
M1P"_"$`MZ0B`O>@!``(`<&5R;'AS:2YC````7U]%3E9?4$%27T-,14%.7U\@
M("`@("`@("`@("`@("``````6&L!`&AK`0!P:P$`>&L!`(!K`0"4:P$`````
M`%!K`0!P:`$``````$AI`0!,:0$`1&L!`'AH`0!,:P$``````#!K`0`X:P$`
M`````"5S+R5S````+W!R;V,O<V5L9B]E>&4``$1Y;F%,;V%D97(Z.F)O;W1?
M1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``````O<')O8R\E:2\E
M<P!E>&4`+@```%!!4E]414U0`````%!!4E]04D]'3D%-10`````Z````)7,E
M<R5S```O````4$523#5,24(`````4$523$Q)0@!015),-4]05`````!015),
M24\``%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X```!0
M05)?1$5"54<```!005)?0T%#2$4```!005)?05)'0P````!005)?05)'5E\P
M``!005)?1TQ/0D%,7T1%0E5'`````%!!4E]'3$]"04Q?5$U01$E2````4$%2
M7U1-4$1)4@``4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`````
M4$%27T-,14%./0``,0```%-94U1%30``)3`R>``````E<R5S)7,E<P````!P
M87(M`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E
M<R!F86EL960@*&5R<FYO/25I*0H``'!A<FP`````+G!A<@`````E<R5S8V%C
M:&4M)7,E<P``)7,E<W1E;7`M)74E<P```"5S)7-T96UP+25U+25U)7,`````
M)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E
M(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@``05)'5@``
M```8````<&5R;``````P````56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E
M8W1O<GD`````)7,Z(&5X96-U=&EO;B!O9B`E<R!F86EL960@*&5R<FYO/25I
M*0H``"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R
M>2`E<R!F86EL960@*&5R<FYO/25I*0H`````+64``"TM``!54T52`````%53
M15).04U%`````%1%35!$25(`5$U0`"]T;7``````3$1?3$E"4D%265]0051(
M`$Q)0E!!5$@`3$E"4D%265]0051(`````$193$1?3$E"4D%265]0051(````
M4TA,24)?4$%42```979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D
M>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L
M;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L
M($!T;7!F:6QE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U
M:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I
M<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID
M:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@
M(B1P87)?=&5M<")]*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@
M+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P
M87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G
M*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M
M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D
M:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*<')I;G0@
M)'1M<"`B(R$O8FEN+W-H"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O
M"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[
M('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*
M<FT@)R(@+B`D=&UP+3YF:6QE;F%M92`N("(G"B(["F-H;6]D(#`W,#`L)'1M
M<"T^9FEL96YA;64["FUY("1C;60@/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D
M978O;G5L;"`R/B8Q("8G.PIC;&]S92`D=&UP.PIS>7-T96TH)&-M9"D["F]U
M=',H<7$H4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C
M;&5A;G5P.B`I"BX@)'1M<"T^9FEL96YA;64I.PI]"GT@?0I"14=)3B!["DEN
M=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI0
M05(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FEF("AE>&ES=',@
M)$5.5GM005)?05)'5E\P?2!A;F0@)$5.5GM005)?05)'5E\P?2`I('L*0$%2
M1U8@/2!M87`@)$5.5GLB4$%27T%21U9?)%\B?2P@*#$@+BX@)$5.5GM005)?
M05)'0WT@+2`Q*3L*)#`@/2`D14Y6>U!!4E]!4D=67S!].PI]"F5L<V4@>PIF
M;W(@*&ME>7,@)45.5BD@>PID96QE=&4@)$5.5GLD7WT@:68@+UY005)?05)'
M5E\O.PI]"GT*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O
M;F9I9R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[
M)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/
M4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D
M7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O
M9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A
M=&%?<&]S*3L*>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E
M;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*
M;7D@)&)U9CL*<V5E:R!?1D@L("TX+"`R.PIR96%D(%]&2"P@)&)U9BP@.#L*
M;&%S="!U;FQE<W,@)&)U9B!E<2`B7&Y005(N<&U<;B(["G-E96L@7T9(+"`M
M,3(L(#(["G)E860@7T9(+"`D8G5F+"`T.PIS965K(%]&2"P@+3$R("T@=6YP
M86-K*").(BP@)&)U9BDL(#(["G)E860@7T9(+"`D8G5F+"`T.PHD9&%T85]P
M;W,@/2`H=&5L;"!?1D@I("T@-#L*;7D@)7)E<75I<F5?;&ES=#L*=VAI;&4@
M*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&
M2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B
M=68["F]U=',H<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*
M;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I
M(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]
M?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*
M<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE
M9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*
M;7D@*"1O=70L("1F:6QE;F%M92D@/2!?=&5M<&9I;&4H)&5X="P@)&-R8RD[
M"FEF("@D;W5T*2!["F)I;FUO9&4H)&]U="D["G!R:6YT("1O=70@)&)U9CL*
M8VQO<V4@)&]U=#L*8VAM;V0@,#<U-2P@)&9I;&5N86UE.PI]"B1005(Z.DAE
M879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ
M2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L
M<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D
M14Y6>U!!4E]414U0?2`I('L*;7D@)&9I;&5N86UE(#T@(B1%3E9[4$%27U1%
M35!]+R1B87-E;F%M921E>'0B.PIO=71S*")32$Q)0CH@)&9I;&5N86UE7&XB
M*3L*;W!E;B!M>2`D;W5T+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$["F)I
M;FUO9&4H)&]U="D["G!R:6YT("1O=70@)&)U9CL*8VQO<V4@)&]U=#L*?0IE
M;'-E('L*)')E<75I<F5?;&ES='LD9G5L;&YA;65](#T*)%!!4CHZ2&5A=GDZ
M.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@
M/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["GT*<F5A9"!?1D@L("1B
M=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U
M;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*
M;7D@)&9I;&5N86UE(#T@9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T@
M?'P@9&\@>PIM>2`D:V5Y.PIF;W)E86-H("AK97ES("5R97%U:7)E7VQI<W0I
M('L*;F5X="!U;FQE<W,@+UQ1)&UO9'5L95Q%)"\["B1K97D@/2`D7SL@;&%S
M=#L*?0ID96QE=&4@)')E<75I<F5?;&ES='LD:V5Y?2!I9B!D969I;F5D*"1K
M97DI.PI](&]R(')E='5R;CL*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1F
M:6QE;F%M92\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F
M:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE
M=U]T;7!F:6QE(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PIP<FEN="`D9F@@
M)&9I;&5N86UE+3Y[8G5F?3L*<V5E:R@D9F@L(#`L(#`I.PIR971U<FX@)&9H
M.PI]"F5L<V4@>PIM>2`H)&]U="P@)&YA;64I(#T@7W1E;7!F:6QE*"<N<&TG
M+"`D9FEL96YA;64M/GMC<F-]*3L*:68@*"1O=70I('L*8FEN;6]D92@D;W5T
M*3L*<')I;G0@)&]U="`D9FEL96YA;64M/GMB=69].PIC;&]S92`D;W5T.PI]
M"F]P96X@;7D@)&9H+"`G/"<L("1N86UE(&]R(&1I92`D(3L*8FEN;6]D92@D
M9F@I.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z
M(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PI]+"!`24Y#*3L*<F5Q=6ER92!8
M4TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE
M879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN
M:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@
M)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU
M;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!
M3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@
M)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE
M;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q
M=6ER95]L:7-T>R1F:6QE;F%M97T["GT*;&%S="!U;FQE<W,@)&)U9B!E<2`B
M4$M<,#`S7#`P-"(["B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L*?0IM
M>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H
M95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I
M>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE="`]
M(#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R
M("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY
M("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?
M<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y
M7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@
M>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!
M4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D
M7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-
M3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*
M<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE
M=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`
M<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R
M.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE
M;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H
M)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@
M>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO="!O
M<&5N(&QO9SH@)"$B.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA
M;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?
M8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H
M*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@
M=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!
M4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]
M"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H
M:79E.CI::7`["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*
M:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R
M(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["F)I;FUO9&4H)&9H*3L*
M8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^
M;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]
M($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92`B4F5A9"`G)'!A<B<@
M97)R;W(Z("0A(CL*?0IM>2`E96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@
M)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]
M?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A
M(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PIL;V-A;"`D+R`](%PT
M.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@4$%2+"`G/"<L("1P87(@;W(@
M9&EE("(D(3H@)'!A<B(["F)I;FUO9&4H4$%2*3L*9&EE("(D<&%R(&ES(&YO
M="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PI]
M"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD
M;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9
M*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92`D(3L*
M8FEN;6]D92@D9F@I.PHD+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A
M=&%?<&]S(#H@=6YD968["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R(#T@
M<V-A;&%R(#Q?1D@^.PII9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO
M861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E
M<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L
M>2A<)&QO861E<BP@)#`I"GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@
M)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@
M979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?
M14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B
M("X@=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K
M*7U["B1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG
M=&@H)'-E="DI*0I]96<["GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*)"\@/2!U
M;F1E9CL*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z
M.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I
M<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@<V]R="!["FQE;F=T:"@D8BD@/#T^
M(&QE;F=T:"@D82D*?2!G<F5P('L*(2]"4T1004XO"GT@9W)E<"!["B@D8G5N
M9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H
M;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]
M*3L*?2!`24Y#.PIM>2`E9FEL97,["B]>7SPH+BLI)"\@86YD("UE("0Q(&%N
M9"`D9FEL97-[)#%]*RL@9F]R(&ME>7,@)3HZ.PHD9FEL97-[)%]]*RL@9F]R
M('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML
M:6)?97AT?3L*;7D@)7=R:71T96X["F9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL
M97,I('L*;7D@*"1N86UE+"`D9FEL92D["F9O<F5A8V@@;7D@)&1I<B`H0&EN
M8RD@>PII9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@
M>PHD9FEL92`]("1?.PIL87-T.PI]"F5L<VEF("@O7BA<421D:7)<15PO*"XJ
M6UY#8UTI*5Q:+VDI('L**"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*;&%S
M=#L*?0IE;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*
M:68@*&UY("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2![
M"B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0IE;'-I9B`H
M+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@
M)#$I.PIL87-T.PI]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N
M9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@
M86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PIO=71S*"!J;VEN("(B
M+`IQ<2A086-K:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@
M)&9I;&4L"G%Q*"(N+BXI"BD["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE
M*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;W!E;B!&
M24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B
M.PIB:6YM;V1E*$9)3$4I.PHD8V]N=&5N="`](#Q&24Q%/CL*8VQO<V4@1DE,
M13L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD8V]N=&5N
M="P@)&9I;&4I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^
M("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N
M="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*;W5T
M<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I*3L*)&9H+3YP<FEN="@B1DE,12(I
M.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI.PHD
M9F@M/G!R:6YT*'-P<FEN=&8H"B(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC
M;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90HI*3L*)&9H+3YP<FEN="AP
M86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI.PHD9F@M/G!R:6YT*"1C;VYT
M96YT*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II
M<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PII
M9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;
M.5TI('L*;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$
M:6=E<W0Z.E-(02T^;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG97-T
M.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E
M($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?=F5R
M<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII
M9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@
M)S4N,SDG*2!["B1C='@M/F%D9&9I;&4H)&]U="P@(F(B*2!I9B`H)&-T>"D[
M"GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD;W5T(BDI
M('L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F
M:"D["GT*?0HD8V%C:&5?;F%M92`]("1C='@@/R`D8W1X+3YH97AD:6=E<W0@
M.B`D;71I;64["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T
M:"`D8V%C:&5?;F%M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^
M<')I;G0H)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M
M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@B7&Y005(N
M<&U<;B(I.PHD9F@M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]
M"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N
M86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A
M9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z
M.EII<#L*?0IM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["FUY("1F:"`]
M($E/.CI&:6QE+3YN97<["B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I
M(&]R(&1I92`B)"$Z("1`(CL*)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F
M:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE
M("(D(3H@)$`B.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,
M:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[4$%2
M7T1%0E5'?3L*;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?
M5$5-4'TB*2D["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO
M=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@
M*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T
M;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X
M="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O
M;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I9WMA
M<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@
M)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[
M4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@
M)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T
M<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y
M(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*?2!E;'-E('L*;W5T<RAQ<2A%
M>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PHD
M;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H;6]D
M*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*
M=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B
M+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)
M9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!=
M"B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?
M4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*
M<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL
M93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I
M;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q
M=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N
M;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U
M8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA
M3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U
M:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q
M=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O
M<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P[
M"G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U
M:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N
M9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB
M.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!005(["G)E<75I<F4@
M4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O
M;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D
M('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C
M86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ
M0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U
M<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ
M<V-A;&%R('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D
M14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2![
M"B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H
M"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2
M(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@
M=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T
M:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@
M9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97
M:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I
M;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]
M("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@
M?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@/7X@<R]<
M5R]?+V<["FUY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R
M+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P
M-S4U.PII9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T
M870H)'!R;V=N86UE*2E;.5TI('L*;W!E;B`H;7D@)&9H+"`B/"(N("1P<F]G
M;F%M92D["G-E96L@)&9H+"`M,3@L(#(["G-Y<W)E860@)&9H+"!M>2`D8G5F
M+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("TU."P@
M,CL*<WES<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O+V<["B1S
M=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U9CL*?0IE
M;'-E('L*;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$
M:6=E<W0Z.E-(02T^;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG97-T
M.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E
M($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?=F5R
M<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII
M9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@
M)S4N,SDG*2!["B1C='@M/F%D9&9I;&4H)'!R;V=N86UE+"`B8B(I(&EF("@D
M8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1P
M<F]G;F%M92(I*2!["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I
M.PIC;&]S92@D9F@I.PI]"GT*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM
M?6-A8VAE+2(@+B`H("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64@
M*3L*?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD14Y6>U!!4E]#3$5!3GT@/2`Q
M.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"(["GT*)$5.
M5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@)'-T;7!D:7(L(#`W-34[
M"FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD
M("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W1E;7!F:6QE('L*
M;7D@*"1E>'0L("1C<F,I(#T@0%\["FUY("@D9F@L("1F:6QE;F%M92D["B1F
M:6QE;F%M92`]("(D<&%R7W1E;7`O)&-R8R1E>'0B.PII9B`H)$5.5GM005)?
M0TQ%04Y]*2!["G5N;&EN:R`D9FEL96YA;64@:68@+64@)&9I;&5N86UE.PIP
M=7-H($!T;7!F:6QE+"`D9FEL96YA;64["GT*96QS92!["G)E='5R;B`H=6YD
M968L("1F:6QE;F%M92D@:68@*"UR("1F:6QE;F%M92D["GT*;W!E;B`D9F@L
M("<^)RP@)&9I;&5N86UE(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PIR971U
M<FXH)&9H+"`D9FEL96YA;64I.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@
M*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'
M3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M
M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N
M86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S
M='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI
M;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H
M)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@
M;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]
M"FEF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*)'!R;V=N86UE
M("X]("1#;VYF:6=[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I
M<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI
M('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@
M)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%
M)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N
M86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[
M7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PHH*"1P<F]G;F%M92`]
M("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US
M("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX
M7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.
M04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\
M(#`I('L*)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA;64B
M.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG
M971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ
M1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@
M<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?
M9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U
M8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK
M*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)
M6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'
M($-!0TA%(%!23T=.04U%($%21T,@05)'5E\P("D@*2!["F1E;&5T92`D14Y6
M>R=005)?)RXD7WT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"
M54<@+RD@>PHD14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N
M)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY("1P
M87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B
M.PII9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.
M?3L*?0IE;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2![
M"FUY("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B
M0TQ%04XB*2D["B1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O
M7E!!4E]#3$5!3CTH7%,K*2\["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D
M<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE
M;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER
M92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I
M9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E
M87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP
M"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#
M+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I
M92!Q<2AP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M
M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*=6YL97-S("UE("1P
M<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@
M/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z
M.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ
M7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T52
M4D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*`!1S_W\!````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'4;`0!=&P$```````$````!`````0````4"```!````
M5`(```$```"G`P``#````%05`0`-````C&<!`!D```#TK@(`&P````0````:
M````^*X"`!P````$````]?[_;[0!`0`%````=`P!``8```!T!0$`"@```#\%
M```+````$````!4``````````P````"P`@`"````*`(``!0````1````%P``
M`"P3`0`1````]!(!`!(````X````$P````@```#^__]OE!(!`/___V\#````
M\/__;[01`0``````````````````````````````````````````````````
M````````````````KP(```````````!@%0$`8!4!`&`5`0!@%0$`8!4!`&`5
M`0!@%0$`8!4!`&`5`0!@%0$`8!4!`&`5`0!@%0$`8!4!`&`5`0!@%0$`8!4!
M`&`5`0!@%0$`8!4!`&`5`0!@%0$`8!4!`&`5`0!@%0$`8!4!`&`5`0!@%0$`
M8!4!`&`5`0!@%0$`8!4!`&`5`0!@%0$`8!4!`&`5`0!@%0$`8!4!`&`5`0!@
M%0$`8!4!`&`5`0!@%0$`8!4!`&`5`0!@%0$`8!4!`&`5`0!@%0$`8!4!`&`5
M`0!@%0$`8!4!`&`5`0!@%0$`8!4!`&`5`0!@%0$`8!4!`&`5`0!@%0$`8!4!
M`&`5`0!@%0$`8!4!`&`5`0!@%0$`8!4!`&`5`0````````````````#_____
MH&L!`$=#0SH@*%5B=6YT=2],:6YA<F\@-"XY+C$M,39U8G5N='4U*2`T+CDN
M,0!'0T,Z("A58G5N='4O3&EN87)O(#0N."XS+3$Q=6)U;G1U,2D@-"XX+C,`
M030```!A96%B:0`!*@````4W+4$`!@H'00@!"0(*!!($$P$4`14!%P,8`1D!
M&@(;`QP!(@$`+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N04))+71A9P`N;F]T
M92YG;G4N8G5I;&0M:60`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU
M+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;"YD>6X`+G)E;"YP;'0`+FEN
M:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N05)-+F5X:61X`"YE:%]F<F%M90`N
M:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N:F-R`"YD>6YA;6EC`"YG;W0`+F1A
M=&$`+F)S<P`N8V]M;65N=``N05)-+F%T=')I8G5T97,``````0```&`5`0``
M```````,``0```!P%0$`````````#``!````=!4!``````````P`!P```#06
M`0`````````,``$````X%@$`````````#``'````?!<!``````````P``0``
M`(`7`0`````````,``<```",%P$`````````#``!````D!<!``````````P`
M!P```%P8`0`````````,``$```!@&`$`````````#```)&$`)&0`)'0`````
M````````````````````````````````````````````````````"P````$`
M```"````5`$!`%0!```9```````````````!`````````!,````'`````@``
M`'`!`0!P`0``(```````````````!``````````A````!P````(```"0`0$`
MD`$``"0```````````````0`````````-````/;__V\"````M`$!`+0!``#`
M`P``!0`````````$````!````#X````+`````@```'0%`0!T!0````<```8`
M```!````!````!````!&`````P````(```!T#`$`=`P``#\%````````````
M``$`````````3@```/___V\"````M!$!`+01``#@````!0`````````"````
M`@```%L```#^__]O`@```)02`0"4$@``8`````8````#````!`````````!J
M````"0````(```#T$@$`]!(``#@````%``````````0````(````<P````D`
M``!"````+!,!`"P3```H`@``!0````P````$````"````'P````!````!@``
M`%05`0!4%0``#```````````````!`````````!W`````0````8```!@%0$`
M8!4``&`#``````````````0````$````@@````$````&````P!@!`,`8``#,
M3@`````````````(`````````(@````!````!@```(QG`0",9P``"```````
M````````!`````````".`````0````(```"49P$`E&<``!!`````````````
M``0`````````E@````$``'""````I*<!`*2G```(````#0`````````$````
M`````*$````!`````@```*RG`0"LIP``!```````````````!`````````"K
M````#@````,```#TK@(`]*X```0```````````````0`````````MP````\`
M```#````^*X"`/BN```$```````````````$`````````,,````!`````P``
M`/RN`@#\K@``!```````````````!`````````#(````!@````,`````KP(`
M`*\````!```&``````````0````(````T0````$````#`````+`"``"P```D
M`0`````````````$````!````-8````!`````P```"2Q`@`DL0``$```````
M````````!`````````#<````"`````,````XL0(`-+$``$00````````````
M``@`````````X0````$````P`````````#2Q``!6```````````````!````
M`0```.H````#``!P``````````"*L0``-0```````````````0`````````!
G`````P``````````````O[$``/H```````````````$`````````
